@@ -4,7 +4,7 @@
 #' computes the log-likelihood for the biomee model fitting several target 
 #' variables for a given set of parameters.
 #' 
-#' @param par A vector containing parameter values for \code{'phiRL',
+#' @param par A named vector containing parameter values for \code{'phiRL',
 #' 'LAI_light', 'tf_base', 'par_mort'} in that order, and for the error terms
 #' corresponding to the target variables, e.g. \code{'err_GPP'} if GPP is a target. 
 #' Make sure that
@@ -29,15 +29,18 @@
 #' @export
 #' 
 #' @examples
-#' \donttest{
+#' \donttest{ # do not run long-running simulations
 #' # Compute the likelihood for a set of
 #' # BiomeE model parameter values
 #' # and the example data
 #' cost_likelihood_biomee(
-#'  par = c(3.5, 3.5, 1, 1,    # model params
-#'          0.5),              # err_GPP
+#'  par = c(phiRL = 3.5, 
+#'          LAI_light = 3.5, 
+#'          tf_base = 1, 
+#'          par_mort = 1,    # model params
+#'          err_GPP = 0.5),  # err_GPP
 #'  obs = biomee_validation,
-#'  drivers = biomee_gs_leuning_drivers,
+#'  drivers = biomee_p_model_drivers,
 #'  targets = c("GPP")
 #' )
 #' }
@@ -50,8 +53,9 @@ cost_likelihood_biomee <- function(
 ){
   
   # predefine variables for CRAN check compliance
-  GPP <- LAI <- Density12 <- plantC <- error <- NULL
+  GPP <- LAI <- Density12 <- plantC <- NULL
   
+  par <- unname(par) # reproduces previous behavior, when par was unnamed
   # Add changed model parameters to drivers, overwriting where necessary.
   drivers$params_species[[1]]$phiRL[]  <- par[1]
   drivers$params_species[[1]]$LAI_light[]  <- par[2]
@@ -65,21 +69,9 @@ cost_likelihood_biomee <- function(
     parallel = FALSE
   )
   
-  # did we spin up
-  spin_up <- drivers$params_siml[[1]]$spinup
-  
-  # drop spinup years if activated
-  # see below
-  if (spin_up){
-    spin_up_years <- drivers$params_siml[[1]]$spinupyears + 1
-  } else {
-    spin_up_years <- 0
-  }
-  
-  # Aggregate variables from the model df taking the last 500 yrs
-  # if spun up
+  # Aggregate variables from the model df taking the last 50 yrs (up to)
   df <- df$data[[1]]$output_annual_tile |>
-    utils::tail(500 - spin_up_years) |>
+    utils::tail(50) |>
     dplyr::summarise(
       GPP = mean(GPP),
       LAI = stats::quantile(LAI, probs = 0.95, na.rm=TRUE),
