@@ -16,8 +16,8 @@
 #'       \item{vpd}{Daytime average vapour pressure deficit in Pa.}
 #'       \item{ppfd}{Photosynthetic photon flux density (PPFD) in
 #'       mol m\eqn{^{-2}} s\eqn{^{-1}}. If all values are NA, it indicates that
-#'       PPFD should be calculated by the SPLASH model.}
-#'       \item{netrad}{Net radiation in W m\eqn{^{-2}}. This is currently
+#'       PPFD should be calculated by the SPLASH model and column ccov.}
+#'       \item{netrad}{Net radiation in W m\eqn{^{-2}}. WARNING: This is currently
 #'       ignored as a model forcing.}
 #'       \item{patm}{Atmospheric pressure in Pa.}
 #'       \item{snow}{Snow in water equivalents mm s\eqn{^{-1}}.}
@@ -26,7 +26,7 @@
 #'       \item{tmax}{Daily maximum air temperature in \eqn{^\circ}C.}
 #'       \item{fapar}{Fraction of photosynthetic active radiation (fAPAR), taking
 #'      values between 0 and 1.}
-#'       \item{co2}{Atmospheric CO\eqn{_2} concentration.}
+#'       \item{co2}{Atmospheric CO\eqn{_2} concentration in ppm.}
 #'       \item{ccov}{Cloud coverage in \%. This is only used when either PPFD or
 #'       net radiation are not prescribed.}
 #'       }
@@ -36,7 +36,7 @@
 #'     \describe{
 #'       \item{spinup}{A logical value indicating whether this simulation does spin-up.}
 #'       \item{spinupyears}{Number of spin-up years.}
-#'       \item{recycle}{Length of standard recycling period, in years.}
+#'       \item{recycle}{Number of first N years of forcing data.frame that are recycled for spin-up.}
 #'       \item{outdt}{An integer indicating the output periodicity.}
 #'       \item{ltre}{A logical value, \code{TRUE} if evergreen tree.}
 #'       \item{ltne}{A logical value, \code{TRUE} if evergreen tree and N-fixing.}
@@ -166,16 +166,20 @@
 #' rsofun P-model output data
 #'
 #' Example output dataset from a p-model run using \code{\link{p_model_drivers}}
+#' See \code{\link{run_pmodel_f_bysite}} for a detailed 
+#' description of the outputs.
 "p_model_output"
 
 #' rsofun P-model output data (using vcmax25 drivers)
 #'
 #' Example output dataset from a p-model run using \code{\link{p_model_drivers_vcmax25}}
+#' See \code{\link{run_pmodel_f_bysite}} for a detailed 
+#' description of the outputs.
 "p_model_output_vcmax25"
 
 #' rsofun BiomeE driver data (Leuning photosynthesis model)
 #' 
-#' Small dataset representing the driver to run the BiomeE-model at the CH-LAE site
+#' Example driver to run the BiomeE-model at the CH-LAE site
 #' using the Leuning photosynthesis specification (and half-hourly time step)
 #' It can also be used together with leaf trait data from CH-LAE (\code{\link{biomee_validation}}) 
 #' to optimize model parameters.
@@ -186,56 +190,48 @@
 #'   \item{params_siml}{Simulation parameters as a data.frame, including
 #'   the following data:
 #'     \describe{
-#'       \item{spinup}{Flag indicating whether this simulation does spin-up.}
-#'       \item{spinupyears}{Number of spin-up years.}
-#'       \item{recycle}{Length of standard recycling period (years).}
-#'       \item{firstyeartrend}{First transient year.}
-#'       \item{nyeartrend}{Number of transient years.}
-#'       \item{steps_per_day}{Time resolution (day-1).}
-#'       \item{do_U_shaped_mortality}{Flag indicating whether U-shaped
-#'         mortality is used.}
-#'       \item{update_annualLAImax}{Flag indicating whether updating
-#'         LAImax according to mineral N in soil.}
-#'       \item{do_closedN_run}{Flag indicating whether doing N closed
-#'         runs to recover N balance enforcing 0.2 kg N m-2 in the inorganic N pool.}
-#'       \item{code_method_photosynth}{String specifying the method of photosynthesis
-#'         used in the model, either "pmodel" or "gs_leuning".document()}
-#'       \item{code_method_mortality}{String indicating the type of mortality in the
+#'       \item{spinup}{Flag indicating whether this simulation does spin-up (deprecated).}
+#'       \item{spinupyears}{Number of spin-up years. Set to 0 for no spinup.}
+#'       \item{recycle}{Number of first N years of forcing data.frame that are recycled for spin-up.}
+#'       \item{firstyeartrend}{Year of first transient year (AD) (optional). Is only used to set years in output data frames. Defaults to 0 if not provided.}
+#'       \item{nyeartrend}{Number of transient years (optional). Determines the length of simulation output after spin-up. Defaults to number of years contained in the forcing data. (If longer than forcing data, last year of forcing is repeated until the end (spin-down).)}
+#'       \item{steps_per_day}{Time resolution of the forcing (day-1).}
+#'       \item{do_U_shaped_mortality}{Flag indicating whether U-shaped mortality is used.}
+#'       \item{do_closedN_run}{Flag indicating whether doing N closed runs to recover N balance enforcing 0.2 kg N m-2 in the inorganic N pool.}
+#'       \item{method_photosynth}{String specifying the method of photosynthesis used in the model, either "pmodel" or "gs_leuning".document()}
+#'       \item{method_mortality}{String indicating the type of mortality in the
 #'         model. One of the following: "dbh" is size-dependent mortality, "const_selfthin"
 #'         is constant self thinning (in development), "cstarvation" is carbon starvation, and
 #'         "growthrate" is growth rate dependent mortality.}
+#'       \item{do_daily_diagnostics}{Whether to output daily diagnostics ('output_daily_tile'). Default: True.}
 #'     }}
 #'   \item{site_info}{Site meta info in a data.frame.
 #' This data structure can be freely used for documenting the dataset, but must include at least the following data:
 #'     \describe{
-#'       \item{lon}{Longitude of the site location.}
-#'       \item{lat}{Latitude of the site location.}
-#'       \item{elv}{Elevation of the site location, in meters.}
+#'       \item{lon}{Longitude of the site location in degrees east.}
+#'       \item{lat}{Latitude of the site location in degrees north.}
+#'       \item{elv}{Elevation of the site location, in meters above sea level.}
 #'     }}
 #'   \item{forcing}{Forcing data.frame used as input
 #'     \describe{
-#'       \item{ppfd}{Photosynthetic photon flux density (mol s-1 m-2)}
+#'       \item{ppfd}{Photosynthetic photon flux density (mol m-2 s-1)}
 #'       \item{tair}{Air temperature (deg C)}
 #'       \item{vpd}{Vapor pressure deficit (Pa)}
 #'       \item{rain}{Precipitation (kgH2O m-2 s-1 == mm s-1)}
 #'       \item{wind}{Wind velocity (m s-1)}
-#'       \item{pair}{Atmospheric pressure (pa)}
-#'       \item{co2}{CO2 atmospheric concentration (ppm)}
+#'       \item{pair}{Atmospheric pressure (Pa)}
+#'       \item{co2}{Atmospheric CO\eqn{_2} concentration in ppm.}
 #'     }}
-#'   \item{params_tile}{Tile-level model parameters, into a single row data.frame, including
-#'   the following data:
+#'   \item{params_tile}{Tile-level model parameters, into a single row data.frame, including the following data:
 #'     \describe{
-#'       \item{soiltype}{Integer indicating the type of soil: Sand = 1, LoamySand = 2,
-#'         SandyLoam = 3, SiltLoam = 4, FrittedClay = 5, Loam = 6, Clay = 7.}
-#'       \item{FLDCAP}{Field capacity (vol/vol). Water remaining in a soil after it
-#'         has been thoroughly saturated and allowed to drain freely.}
-#'       \item{WILTPT}{Wilting point (vol/vol). Water content of a soil at which
-#'       plants wilt and fail to recover.}
-#'       \item{K1}{Fast soil C decomposition rate (year\eqn{^{-1}}).}
-#'       \item{K2}{Slow soil C decomposition rate (year\eqn{^{-1}}).}
-#'       \item{K_nitrogen}{Mineral Nitrogen turnover rate (year\eqn{^{-1}}).}
+#'       \item{soiltype}{Integer indicating the type of soil: Sand = 1, LoamySand = 2, SandyLoam = 3, SiltLoam = 4, FrittedClay = 5, Loam = 6, Clay = 7.}
+#'       \item{FLDCAP}{Field capacity (vol/vol). Water remaining in a soil after it has been thoroughly saturated and allowed to drain freely.}
+#'       \item{WILTPT}{Wilting point (vol/vol). Water content of a soil at which plants wilt and fail to recover.}
+#'       \item{K1}{Fast soil C decomposition rate (yr\eqn{^{-1}}).}
+#'       \item{K2}{Slow soil C decomposition rate (yr\eqn{^{-1}}).}
+#'       \item{K_nitrogen}{Mineral Nitrogen turnover rate (yr\eqn{^{-1}}).}
 #'       \item{MLmixRatio}{Ratio of C and N returned to litters from microbes.}
-#'       \item{etaN}{N loss rate through runoff (organic and mineral) (year\eqn{^{-1}}).}
+#'       \item{etaN}{N loss rate through runoff (organic and mineral) (yr\eqn{^{-1}}).}
 #'       \item{LMAmin}{Minimum LMA, leaf mass per unit area, kg C m\eqn{^{-2}}.}
 #'       \item{fsc_fine}{Fraction of fast turnover carbon in fine biomass.}
 #'       \item{fsc_wood}{Fraction of fast turnover carbon in wood biomass.}
@@ -244,70 +240,90 @@
 #'       \item{retransN}{Retranslocation coefficient of nitrogen.}
 #'       \item{f_initialBSW}{Coefficient for setting up initial sapwood.}
 #'       \item{f_N_add}{Re-fill of N for sapwood.}
-#'       \item{tf_base}{Calibratable scalar for respiration, used to increase LUE
-#'         levels.}
+#'       \item{tf_base}{Calibratable scalar for respiration, used to increase LUE levels.}
 #'       \item{par_mort}{Canopy mortality parameter.}
 #'       \item{par_mort_under}{Parameter for understory mortality.}
 #'     }}
-#'   \item{params_species}{A data.frame containing species-specific model parameters,
-#'       with one species per row, including the following data:
+#'   \item{params_species}{A data.frame containing species-specific model parameters, with one species per row, including the following data:
 #'     \describe{
+#'     \item{The following columns pertaining to the \bold{plant type}:}{\describe{
 #'       \item{lifeform}{Integer set to 0 for grasses and 1 for trees.}
 #'       \item{phenotype}{Integer set to 0 for deciduous and 1 for evergreen.}
-#'       \item{pt}{Integer indicating the type of plant according to photosynthesis:
-#'         0 for C3; 1 for C4}
-#'       \item{alpha_FR}{Fine root turnonver rate (year\eqn{^{-1}}).}
+#'       \item{pt}{Integer indicating the type of plant according to photosynthesis: 0 for C3; 1 for C4}
+#'     }}\item{The following columns pertaining to the \bold{root parameters}:}{\describe{
+#'       \item{alpha_FR}{Fine root turnover rate (yr\eqn{^{-1}}).}
 #'       \item{rho_FR}{Material density of fine roots (kg C m\eqn{^{-3}}).}
 #'       \item{root_r}{Radius of the fine roots, in m.}
 #'       \item{root_zeta}{e-folding parameter of root vertical distribution, in m.}
-#'       \item{Kw_root}{Fine root water conductivity (mol m\eqn{^{-2}}
-#'         s\eqn{^{-1}} MPa\eqn{^{-1}}).}
+#'       \item{Kw_root}{Fine root water conductivity (mol m\eqn{^{-2}} s\eqn{^{-1}} MPa\eqn{^{-1}}).}
 #'       \item{leaf_size}{Characteristic leaf size.}
+#'     }}\item{The following columns pertaining to the \bold{photosynthesis parameters}:}{\describe{
 #'       \item{Vmax}{Max RuBisCo rate, in mol m\eqn{^{-2}} s\eqn{^{-1}}.}
-#'       \item{Vannual}{Annual productivity per unit area at full sun (kg C
-#'         m\eqn{^{-2}} year\eqn{^{-2}}).}
+#'       \item{Vannual}{Annual productivity per unit area at full sun (kg C m\eqn{^{-2}} year\eqn{^{-2}}).}
 #'       \item{wet_leaf_dreg}{Wet leaf photosynthesis down-regulation.}
 #'       \item{m_cond}{Factor of stomatal conductance.}
 #'       \item{alpha_phot}{Photosynthesis efficiency.}
-#'       \item{gamma_L}{Leaf respiration coefficient, in year\eqn{^{-1}}.}
+#'       \item{gamma_L}{Leaf respiration coefficient, in yr\eqn{^{-1}}.}
 #'       \item{gamma_LN}{Leaf respiration coefficient per unit N.}
-#'       \item{gamma_SW}{Sapwood respiration rate, in kg C m\eqn{^{-2}} year\eqn{^{-1}}.}
-#'       \item{gamma_FR}{Fine root respiration rate, kg C kg C\eqn{^{-1}}
-#'         year\eqn{^{-1}}.}
-#'       \item{tc_crit}{Critical temperature triggerng offset of phenology, in Kelvin.}
-#'       \item{tc_crit_on}{Critical temperature triggerng onset of phenology, in Kelvin.}
+#'       \item{gamma_SW}{Sapwood respiration rate, in kg C m\eqn{^{-2}} yr\eqn{^{-1}}.}
+#'       \item{gamma_FR}{Fine root respiration rate, kg C kg C\eqn{^{-1}} yr\eqn{^{-1}}.}
+#'       \item{tk_crit}{Critical temperature triggerng offset of phenology, in Kelvin.}
+#'       \item{tk_crit_on}{Critical temperature triggerng onset of phenology, in Kelvin.}
 #'       \item{gdd_crit}{Critical value of GDD5 for turning ON growth season.}
 #'       \item{betaON}{Critical soil moisture for phenology onset.}
 #'       \item{betaOFF}{Critical soil moisture for phenology offset.}
+#'     }}\item{The following columns pertaining to the \bold{allometry parameters}:}{\describe{
+#'       \item{alphaHT}{Coefficient for allometry (height = alphaHT * DBH_m ** thetaHT), in m m\eqn{^{-thetaHT}}.}
+#'       \item{thetaHT}{Coefficient for allometry (height = alphaHT * DBH_m ** thetaHT), in m m\eqn{^{-thetaHT}}.}
+#'       \item{alphaCA}{Coefficient for allometry (projected crown area = pi * (alphaCA * DBH_m) ** thetaCA), in m\eqn{^{2/thetaCA-1}}.}
+#'       \item{thetaCA}{Coefficient for allometry (projected crown area = pi * (alphaCA * DBH_m) ** thetaCA), unitless. Dybzinski (eq. G1) showed that thetaCA = theatBM - 1.}
+#'       \item{alphaBM}{Coefficient for allometry (biomass = alphaBM * DBH ** thetaBM), in kg C m\eqn{^{-thetaBM}}.}
+#'       \item{thetaBM}{Coefficient for allometry (biomass = alphaBM * DBH ** thetaBM), unitless. Dybzinski (eq. G1) showed that thetaCA = theatBM - 1.}
+#'     }}\item{The following columns pertaining to the \bold{reproduction parameters}:}{\describe{
 #'       \item{seedlingsize}{Initial size of seedlings, in kg C per individual.}
-#'       \item{LNbase}{Basal leaf N per unit area, in kg N m\eqn{^{-2}}.}
-#'       \item{lAImax}{Maximum crown LAI (leaf area index).}
-#'       \item{Nfixrate0}{Reference N fixation rate (kg N kg C\eqn{^{-1}} root).}
-#'       \item{NfixCost0}{Carbon cost of N fixation (kg C kg N\eqn{^{-1}}).}
-#'       \item{phiCSA}{Ratio of sapwood area to leaf area.}
-#'       \item{mortrate_d_c}{Canopy tree mortality rate (year\eqn{^{-1}}).}
-#'       \item{mortrate_d_u}{Understory tree mortality rate (year\eqn{^{-1}}).}
 #'       \item{maturalage}{Age at which trees can reproduce (years).}
 #'       \item{v_seed}{Fraction of G_SF to G_F.}
-#'       \item{fNSmax}{Multiplier for NSNmax as sum of potential bl and br.}
+#'     }}\item{The following columns pertaining to the \bold{mortality parameters}:}{\describe{
+#'       \item{mortrate_d_c}{Canopy tree mortality rate (yr\eqn{^{-1}}).}
+#'       \item{mortrate_d_u}{Understory tree mortality rate (yr\eqn{^{-1}}).}
+#'     }}\item{The following columns pertaining to the \bold{leaf parameters}:}{\describe{
 #'       \item{LMA}{Leaf mass per unit area (kg C m\eqn{^{-2}}).}
+#'       \item{leafLS}{TODO}
+#'       \item{LNbase}{Basal leaf N per unit area, in kg N m\eqn{^{-2}}.}
+#'       \item{CNleafsupport}{TODO}
 #'       \item{rho_wood}{Wood density (kg C m\eqn{^{-3}}).}
-#'       \item{alphaBM}{Coefficient for allometry (biomass = alphaBM * DBH ** thetaBM).}
-#'       \item{thetaBM}{Coefficient for allometry (biomass = alphaBM * DBH ** thetaBM).}
-#'       \item{kphio}{Quantum yield efficiency \eqn{\varphi_0},
-#'        in mol mol\eqn{^{-1}}.}
+#'       \item{taperfactor}{TODO}
+#'       \item{lAImax}{Maximum crown LAI (leaf area index).}
+#'       \item{tauNSC}{TODO}
+#'       \item{fNSmax}{Multiplier for NSNmax as sum of potential bl and br.}
+#'       \item{phiCSA}{Ratio of sapwood area to leaf area.}
+#'     }}\item{The following columns pertaining to the \bold{C/N ratios for plant pools}:}{\describe{
+#'       \item{CNleaf0}{TODO}
+#'       \item{CNsw0}{TODO}
+#'       \item{CNwood0}{TODO}
+#'       \item{CNroot0}{TODO}
+#'       \item{CNseed0}{TODO}
+#'       \item{Nfixrate0}{Reference N fixation rate (kg N kg C\eqn{^{-1}} root).}
+#'       \item{NfixCost0}{Carbon cost of N fixation (kg C kg N\eqn{^{-1}}).}
+#'       \item{internal_gap_frac}{TODO}
+#'     }}\item{The following columns pertaining to the \bold{calibratable parameters}:}{\describe{
+#'       \item{kphio}{Quantum yield efficiency \eqn{\varphi_0}, in mol mol\eqn{^{-1}}.}
 #'       \item{phiRL}{Ratio of fine root to leaf area.}
 #'       \item{LAI_light}{Maximum LAI limited by light.}
-#'     }}
+#'     }}}}
 #'   \item{init_cohort}{A data.frame of initial cohort specifications, including
 #'   the following data:
 #'     \describe{
 #'       \item{init_cohort_species}{Index of a species described in param_species.}
-#'       \item{init_cohort_nindivs}{Initial individual density, in individuals per
-#'         m\eqn{^{2}}.}
+#'       \item{init_cohort_nindivs}{Initial individual density, in individuals per m\eqn{^{2}}.}
+#'       \item{init_cohort_bl}{Initial biomass of leaf, in kg C per individual.}
+#'       \item{init_cohort_br}{Initial biomass of fine root, in kg C per individual.}
 #'       \item{init_cohort_bsw}{Initial biomass of sapwood, in kg C per individual.}
-#'       \item{init_cohort_bHW}{Initial biomass of heartwood, in kg C per tree.}
-#'       \item{init_cohort_nsc}{Initial non-structural biomass.}
+#'       \item{init_cohort_bHW}{Initial biomass of heartwood, in kg C per individual.}
+#'       \item{init_cohort_seedC}{Initial biomass of seed, in kg C per individual.}
+#'       \item{init_cohort_nsc}{Initial non-structural biomass, in kg C per individual.}
+#'       \item{lu_index}{Land use type this cohorts belongs to (given as index in init_lu aray).
+#'        Default: 0 (attach to all LU types except thoses which do not accept vegetation -- cf  init_lu.vegetated).}
 #'     }}
 #'   \item{init_soil}{A data.frame of initial soil pools, including
 #'   the following data:
@@ -315,15 +331,33 @@
 #'       \item{init_fast_soil_C}{Initial fast soil carbon, in kg C m\eqn{^{-2}}.}
 #'       \item{init_slow_soil_C}{Initial slow soil carbon, in kg C m\eqn{^{-2}}.}
 #'       \item{init_Nmineral}{Mineral nitrogen pool, in kg N m\eqn{^{-2}}.}
-#'       \item{N_input}{Annual nitrogen input to soil N pool, in kg N m\eqn{^{-2}}
-#'         year\eqn{^{-1}}.}
+#'       \item{N_input}{Annual nitrogen input to soil N pool, in kg N m\eqn{^{-2}} yr\eqn{^{-1}}.}
 #'     }}
+#'   \item{init_lu}{A data.frame of initial land unit (LU) specifications, including
+#'     the following data:
+#'     \describe{
+#'       \item{fraction}{Initial grid cell fraction occupied by this LU, dimensionless (0 to 1) or m\eqn{^{-2}} LU area per m\eqn{^{-2}} grid cell area.
+#'         The sum of all fractions is typically equal to 1, but may be less in which case the difference is the fraction of the grid cell occupied by ice/water.}
+#'       \item{preset}{Predefined land use type (optional). One of: 'unmanaged', 'urban', 'cropland', 'pasture'. See below for meaning of these presets. Leave empty to not use any preset.}
+#'       \item{vegetated}{Whether this LU accepts vegetation. Default for preset 'urban': False, default for other presets: True.}
+#'       \item{extra_N_input}{Additional inorg N supply (to account for N fertiliser application), in kg m-2 yr-1. Default for preset 'cropland': 0.01, default other presets: 0.}
+#'       \item{extra_turnover_rate}{Additional soil turnover rate (to account for soil management such as tillage), dimensionless. Default for preset 'cropland': 0.2, default for other presets: 0.}
+#'       \item{oxidized_litter_fraction}{Fraction of above-ground turnover that is directly oxidized (crop and grass harvest), dimensionless.
+#'         Default for preset 'cropland': 0.9, default for preset 'pasture': 0.4, default for other presets: 0.}
+#'     }}
+#'   \item{luc_forcing}{Array of land use change (LUC) used during transient phase.
+#'      During spinup, the initial land unit fractions are used (i.e. no transition).
+#'      If there are more transient years than provided LUC data, the last state is maintained until the end of the transient phase (i.e. no transition).
+#'      The array is a nxn square matrix, where n is the number of LU (i.e. dimension of init_lu).
+#'      Each entry f(i, j) expresses the grid cell fraction of LU i (row) being transfered to LU j (column).
+#'      I.e. same units as \code{init_lu$fraction}.
+#'      Self transitions are allowed, meaning that a part of the land unit is clear cut, but the area remains in the same land use.}
 #' }
 "biomee_gs_leuning_drivers"
 
 #' rsofun BiomeE driver data (P-model photosynthesis model)
 #' 
-#' Small dataset representing the driver to run the BiomeE-model at the CH-LAE site
+#' Example driver data to run the BiomeE-model at the CH-LAE site
 #' using the P-model photosynthesis specification (and daily time step).
 #' It can also be used together with leaf trait data from CH-LAE (\code{\link{biomee_validation}}) 
 #' to optimize model parameters.
@@ -333,6 +367,17 @@
 #' @inherit biomee_gs_leuning_drivers source
 "biomee_p_model_drivers"
 
+#' rsofun BiomeE driver data (P-model photosynthesis model) with LULUC
+#'
+#' Example driver data to run the BiomeE-model at the CH-LAE site
+#' using the P-model photosynthesis specification (and daily time step).
+#' It provides an example of land use change (LUC).
+#'
+#' @format See \code{\link{biomee_gs_leuning_drivers}}
+#'
+#' @inherit biomee_gs_leuning_drivers source
+"biomee_p_model_luluc_drivers"
+
 #' rsofun BiomeE targets validation data
 #'
 #' Small example dataset of target observations (leaf trait data) at the CH-LAE site
@@ -349,12 +394,20 @@
 #' Dataset. https://doi.org/10.18140/FLX/1440134
 "biomee_validation"
 
-#' rsofun BiomeE (P-model) output data
-#'
-#' Example output dataset from a BiomeE-model run (p-model)
-"biomee_p_model_output"
-
 #' rsofun BiomeE (gs_leuning) output data
 #'
-#' Example output dataset from a BiomeE-model run (gs_leuning)
+#' Example output dataset from a BiomeE-model run using divers \code{\link{biomee_gs_leuning_drivers}}
+#' See \code{\link{runread_biomee_f}} and \code{\link{run_biomee_f_bysite}} for a detailed description of the outputs.
 "biomee_gs_leuning_output"
+
+#' rsofun BiomeE (P-model) output data
+#'
+#' Example output dataset from a BiomeE-model run using divers \code{\link{biomee_p_model_drivers}}
+#' See \code{\link{runread_biomee_f}} and \code{\link{run_biomee_f_bysite}} for a detailed description of the outputs.
+"biomee_p_model_output"
+
+#' rsofun BiomeE (P-model) output data
+#'
+#' Example output dataset from a BiomeE-model run using divers \code{\link{biomee_p_model_luluc_drivers}}
+#' See \code{\link{runread_biomee_f}} and \code{\link{run_biomee_f_bysite}} for a detailed description of the outputs.
+"biomee_p_model_luluc_output"
