@@ -5,15 +5,15 @@ module md_biosphere_pmodel
   ! Does not contain any input/output; this is done in SR sofun.
   !----------------------------------------------------------------
   use md_params_core
-  use md_classdefs
   use md_waterbal, only: waterbal, solar, getpar_modl_waterbal
   use md_gpp_pmodel, only: getpar_modl_gpp, gpp
   use md_vegdynamics_pmodel, only: vegdynamics
-  use md_tile_pmodel, only: tile_type, tile_fluxes_type, initglobal_tile, initdaily_tile_fluxes, &
+  use md_tile_pmodel, only: tile_type, tile_fluxes_type, init_tile, initdaily_tile_fluxes, &
     getpar_modl_tile, diag_daily
   use md_plant_pmodel, only: getpar_modl_plant
   use md_sofunutils, only: calc_patm
   use md_soiltemp, only: soiltemp
+  use md_track_vegetation_d13c, only: track_vegetation_d13c
 
   implicit none
 
@@ -46,7 +46,7 @@ contains
     !----------------------------------------------------------------
     ! INITIALISATIONS
     !----------------------------------------------------------------
-    if (myinterface%steering%init) then
+    if (myinterface%steering_state%init) then
 
       ! set to true on first simulation year and first day
       init_daily = .true.
@@ -65,8 +65,8 @@ contains
       !----------------------------------------------------------------
       ! Initialise pool variables and/or read from restart file (not implemented)
       !----------------------------------------------------------------
-      ! if (verbose) print*, 'initglobal_() ...'
-      call initglobal_tile( tile(:) )
+      ! if (verbose) print*, 'init_() ...'
+      call init_tile( tile(:) )
       ! if (verbose) print*, '... done'
 
     endif 
@@ -89,7 +89,7 @@ contains
         doy=doy+1
 
         ! if (verbose) print*,'----------------------'
-        ! if (verbose) print*,'YEAR, Doy ', myinterface%steering%year, doy
+        ! if (verbose) print*,'YEAR, Doy ', myinterface%steering_state%year, doy
         ! if (verbose) print*,'----------------------'
 
         !----------------------------------------------------------------
@@ -137,10 +137,16 @@ contains
                   myinterface%climate(doy), &
                   myinterface%grid, &
                   init_daily, &
-                  myinterface%params_siml%in_ppfd &
+                  myinterface%params_siml%in_ppfd, &
+                  myinterface%tc_home &
                   )
         ! if (verbose) print*,'... done'
 
+        !----------------------------------------------------------------
+        ! keep track of 13C isotopic signature in "virtual leaf biomass"
+        !----------------------------------------------------------------
+        call track_vegetation_d13c( tile(:), tile_fluxes(:) )
+
         !----------------------------------------------------------------
         ! get soil moisture, and runoff
         !----------------------------------------------------------------
@@ -160,15 +166,15 @@ contains
                       tile(:)%soil, &
                       myinterface%climate(:)%dtemp, &
                       doy, &
-                      myinterface%steering%init, &
-                      myinterface%steering%finalize &
+                      myinterface%steering_state%init, &
+                      myinterface%steering_state%finalize &
                       )
         ! if (verbose) print*, '... done'
 
         !----------------------------------------------------------------
         ! daily diagnostics (e.g., sum over plant within canopy)
         !----------------------------------------------------------------
-        call diag_daily(tile(:), tile_fluxes(:))
+        call diag_daily( tile(:), tile_fluxes(:) )
 
         !----------------------------------------------------------------
         ! populate function return variable
@@ -194,6 +200,8 @@ contains
         out_biosphere%wcont(doy)   = tile(1)%soil%phy%wcont
         out_biosphere%snow(doy)    = tile(1)%soil%phy%snow
         out_biosphere%cond(doy)    = tile_fluxes(1)%canopy%dcn
+        out_biosphere%cleaf(doy)   = tile(1)%plant(1)%pleaf%c12
+        out_biosphere%cleafd13c(doy) = tile(1)%plant(1)%pleaf%d13
 
         init_daily = .false.
 
