@@ -3,23 +3,30 @@ module md_forcing_biomee
   ! Module containing treatment of forcing for BiomeE, linking
   ! what's obtained from R through SR biomee_f and what's needed by BiomeE.
   !----------------------------------------------------------------
-  use, intrinsic :: iso_fortran_env, dp=>real64, sp=>real32, in=>int32
-  use md_params_core, only: ntstepsyear, ndayyear, kTkelvin, kfFEC
+  use, intrinsic :: iso_fortran_env, dp=>real64
+  use md_params_core, only: ndayyear, kTkelvin, kfFEC
   implicit none
 
   private
-  public climate_type, getclimate
+  public climate_type
+
+  public getclimate
+
+  ! Number of parameters
+  integer, public, parameter :: nvars_forcing = 8
 
   type :: climate_type
     real    :: ppfd          ! mol m-2 s-1
     real    :: radiation     ! W m-2 (SW downwelling, computed from ppfd)
-    real    :: Tair          ! air temperature,  K
+    real    :: TairK         ! air temperature,  K
+    real    :: TairC         ! air temperature,  C
     real    :: vpd           ! vapor pressure deficit (Pa)
     real    :: rain          ! kgH2O m-2 s-1
     real    :: windU         ! wind velocity (m s-1)
     real    :: P_air         ! pa
     real    :: CO2           ! mol CO2/mol dry air
     real    :: RH            ! relative humidity (fraction < 1, computed from vpd and Tair)
+    real    :: d13c_atm      ! atmospheric delta-13C isotopic signature, permil
   end type climate_type
 
 contains
@@ -34,21 +41,27 @@ contains
     ! arguments
     integer, intent(in) :: nt ! number of time steps
     integer, intent(in) :: ntstepsyear   ! number of time steps per year of model
-    real(kind=dp),  dimension(nt,7), intent(in)  :: forcing  ! array containing all temporally varying forcing data
+    real(kind=dp),  dimension(nt,nvars_forcing), intent(in)  :: forcing  ! array containing all temporally varying forcing data
     integer, intent(in) :: climateyear_idx
 
     ! local variables
-    integer :: idx_start, idx_end, it
+    integer :: idx_start, idx_end, it, forcing_years, idx
 
     ! function return variable
     type(climate_type), dimension(ntstepsyear) :: out_climate
 
-    idx_start = (climateyear_idx - 1) * ntstepsyear + 1
+    forcing_years = size(forcing(:, 1)) / ntstepsyear
+    ! If we are simulating more years than the forcing array contains,
+    ! We repeat the last year of the forcing.
+    idx = MIN(climateyear_idx, forcing_years)
+
+    idx_start = (idx - 1) * ntstepsyear + 1
     idx_end   = idx_start + ntstepsyear - 1
 
     ! This is to read from ORNL file
     out_climate%ppfd      = real(forcing(idx_start:idx_end, 1))
-    out_climate%Tair      = real(forcing(idx_start:idx_end, 2)) + kTkelvin
+    out_climate%TairC     = real(forcing(idx_start:idx_end, 2))
+    out_climate%TairK     = real(forcing(idx_start:idx_end, 2)) + kTkelvin
     out_climate%vpd       = real(forcing(idx_start:idx_end, 3))
     out_climate%rain      = real(forcing(idx_start:idx_end, 4))
     out_climate%windU     = real(forcing(idx_start:idx_end, 5))
@@ -58,9 +71,11 @@ contains
     out_climate%radiation = out_climate%ppfd / (kfFEC * 1.0e-6)
 
     do it=1,ntstepsyear
-      out_climate(it)%RH  = calc_rh_vpd( out_climate(it)%vpd, (out_climate(it)%Tair - kTkelvin) )
+      out_climate(it)%RH  = calc_rh_vpd( out_climate(it)%vpd, (out_climate(it)%TairC) )
     end do
 
+    out_climate%d13c_atm = real(forcing(idx_start:idx_end, 8))
+
   end function getclimate
 
   function calc_rh_vpd( vpd, tc ) result( rh )
