@@ -15,7 +15,7 @@ module md_forcing_pmodel
     getclimate, getco2, getfapar, get_fpc_grid, vegcover_type
 
   type climate_type
-    real(kind=sp) :: dtemp  ! daily mean air temperature, deg C
+    real(kind=sp) :: dtemp  ! daytime mean air temperature, deg C
     real(kind=sp) :: dtmin  ! daily minimum air temperature, deg C
     real(kind=sp) :: dtmax  ! daily maximum air temperature, deg C
     real(kind=sp) :: dprec  ! mm s-1
@@ -25,6 +25,7 @@ module md_forcing_pmodel
     real(kind=sp) :: dppfd  ! mol m-2 s-1
     real(kind=sp) :: dnetrad! W m-2
     real(kind=sp) :: dpatm  ! Pa
+    real(kind=sp) :: d13c_atm ! atmospheric delta-13C isotopic signature, permil
   end type climate_type
 
   type vegcover_type
@@ -59,13 +60,17 @@ contains
     logical, intent(in) :: in_netrad
 
     ! local variables
-    integer :: idx_start, idx_end
-    ! integer, dimension(2) :: shape_forcing
+    integer :: idx_start, idx_end, forcing_years, idx
 
     ! function return variable
     type( climate_type ), dimension(ndayyear) :: out_climate
 
-    idx_start = (climateyear_idx - 1) * ndayyear + 1
+    forcing_years = size(forcing(:, 1)) / ndayyear
+    ! If we are simulating more years than the forcing array contains,
+    ! We repeat the last year of the forcing.
+    idx = MIN(climateyear_idx, forcing_years)
+
+    idx_start = (idx - 1) * ndayyear + 1
     idx_end   = idx_start + ndayyear - 1
     
     ! Test if forcing dimensions are correct
@@ -94,6 +99,8 @@ contains
     out_climate(:)%dpatm   = real(forcing(idx_start:idx_end, 10))
     out_climate(:)%dtmin   = real(forcing(idx_start:idx_end, 11))
     out_climate(:)%dtmax   = real(forcing(idx_start:idx_end, 12))
+    
+    out_climate(:)%d13c_atm = real(forcing(idx_start:idx_end, 13))
 
   end function getclimate
 
@@ -113,11 +120,16 @@ contains
 
     ! local variables 
     integer :: readyear_idx
-    integer :: idx_start, idx_end
+    integer :: idx_start, idx_end, forcing_years, idx
 
     readyear_idx = forcingyear - firstyeartrend + 1
 
-    idx_start = (readyear_idx - 1) * ndayyear + 1
+    forcing_years = size(forcing(:, 1)) / ndayyear
+    ! If we are simulating more years than the forcing array contains,
+    ! We repeat the last year of the forcing.
+    idx = MIN(readyear_idx, forcing_years)
+
+    idx_start = (idx - 1) * ndayyear + 1
     idx_end   = idx_start + ndayyear - 1
 
     pco2 = sum(real(forcing(idx_start:idx_end, 8)))/ndayyear
@@ -138,9 +150,14 @@ contains
     type( vegcover_type ), dimension(ndayyear) :: out_vegcover
 
     ! local variables 
-    integer :: idx_start, idx_end
+    integer :: idx_start, idx_end, forcing_years, idx
 
-    idx_start = (forcingyear_idx - 1) * ndayyear + 1
+    forcing_years = size(forcing(:, 1)) / ndayyear
+    ! If we are simulating more years than the forcing array contains,
+    ! We repeat the last year of the forcing.
+    idx = MIN(forcingyear_idx, forcing_years)
+
+    idx_start = (idx - 1) * ndayyear + 1
     idx_end   = idx_start + ndayyear - 1
 
     out_vegcover(:)%dfapar = real(forcing(idx_start:idx_end, 9))
