@@ -5,31 +5,34 @@ module md_gpp_biomee
   ! Code for gs_leuning photosynthesis option is adopted from BiomeE https://doi.org/10.5281/zenodo.7125963.
   ! Code for pmodel photosynthesis option is for P-model (Stocker et al., 2020 GMD)
   !----------------------------------------------------------------
-  use datatypes
-  use md_interface_biomee, only: myinterface
+  use md_vegetation_tile_biomee
+  use md_interface_in_biomee, only: inputs
   use md_soil_biomee, only: water_supply_layer
   use md_sofunutils, only: calc_esat
 
   implicit none
 
   private
-  public gpp, getpar_modl_gpp
+  public gpp
 
   !-----------------------------------------------------------------------
   ! P-model parameters created here for pmodel option. takes no effect in gs_leuning option
   !-----------------------------------------------------------------------
   type paramstype_gpp
-    real :: beta         ! Unit cost of carboxylation (dimensionless)
-    real :: soilm_thetastar
-    real :: soilm_betao
-    real :: rd_to_vcmax  ! Ratio of Rdark to Vcmax25, number from Atkin et al., 2015 for C3 herbaceous
-    real :: tau_acclim   ! acclimation time scale of photosynthesis (d)
-    real :: kc_jmax
+    real :: beta = 146.0        ! Unit cost of carboxylation (dimensionless)
+
+    ! Apply identical temperature ramp parameter for all PFTs
+    real :: tau_acclim = 30.0   ! acclimation time scale of photosynthesis (d)
+    real :: soilm_thetastar = 0.6 * 250
+    real :: soilm_betao = 0.0
+
+    real :: rd_to_vcmax = 0.014 ! Ratio of Rdark to Vcmax25, number from Atkin et al., 2015 for C3 herbaceous
+    real :: kc_jmax = 0.41      ! Jmax cost ratio
 
     ! these should be species-specific, temporary solution to put them here
-    real :: kphio        ! quantum yield efficiency at optimal temperature, phi_0 (Stocker et al., 2020 GMD Eq. 10)
-    real :: kphio_par_a  ! shape parameter of temperature-dependency of quantum yield efficiency
-    real :: kphio_par_b  ! optimal temperature of quantum yield efficiency (deg C)
+    real :: kphio = 0.05        ! quantum yield efficiency at optimal temperature, phi_0 (Stocker et al., 2020 GMD Eq. 10 and Eq. 20)
+    real :: kphio_par_a = 0.0   ! shape parameter of temperature-dependency of quantum yield efficiency
+    real :: kphio_par_b = 25.0  ! optimal temperature of quantum yield efficiency (deg C)
 
   end type paramstype_gpp
 
@@ -37,7 +40,7 @@ module md_gpp_biomee
 
 contains
 
-  subroutine gpp( forcing, vegn, init )
+  subroutine gpp( forcing, vegn )
     !//////////////////////////////////////////////////////////////////////
     ! GPP
     ! Calculates light availability and photosynthesis for each cohort 
@@ -51,21 +54,21 @@ contains
     ! Subroutines from BiomeE-Allocation
     !------------------------------------------------------------------------
     use md_forcing_biomee, only: climate_type
-    use md_photosynth, only: pmodel, zero_pmodel, outtype_pmodel, calc_ftemp_inst_rd
+    use md_photosynth, only: pmodel, zero_pmodel, outtype_pmodel, calc_ftemp_inst_rd, calc_bigdelta
     use md_photosynth, only: calc_kphio_temp, calc_soilmstress
     use md_params_core, only: kTkelvin, kfFEC, c_molmass
     use md_sofunutils, only: dampen_variability
 
     type(climate_type), intent(in):: forcing
     type(vegn_tile_type), intent(inout) :: vegn
-    logical, intent(in) :: init   ! is true on the very first simulation day (first subroutine call of each gridcell)
 
     ! local variables used for BiomeE-Allocation part
     type(cohort_type), pointer :: cc
-    integer, parameter :: nlayers_max = 9                  ! maximum number of canopy layers to be considered 
+    type(cohort_stack_item), pointer :: it
+    integer :: i
     real   :: rad_top                                      ! downward radiation at the top of the canopy, W/m2
     real   :: rad_net                                      ! net radiation absorbed by the canopy, W/m2
-    real   :: Tair, TairK                                  ! air temperature, degC and degK
+    real   :: TairC, TairK                                 ! air temperature, deg C and deg K
     real   :: cana_q                                       ! specific humidity in canopy air space, kg/kg
     real   :: cana_co2                                     ! co2 concentration in canopy air space, mol CO2/mol dry air
     real   :: p_surf                                       ! surface pressure, Pa
@@ -74,46 +77,40 @@ contains
     real   :: psyn                                         ! net photosynthesis, mol C/(m2 of leaves s)
     real   :: resp                                         ! leaf respiration, mol C/(m2 of leaves s)
     real   :: w_scale2, transp                             ! mol H20 per m2 of leaf per second
-    real   :: kappa                                        ! light extinction coefficient of crown layers
     real   :: f_light(nlayers_max+1)                       ! incident light fraction at top of a given layer
     real   :: LAIlayer(nlayers_max)                        ! leaf area index per layer, corrected for gaps (representative for the tree-covered fraction)
-    real   :: accuCAI, f_gap
+    real   :: accuCAI
     real   :: par                                          ! just for temporary use
-    real, dimension(vegn%n_cohorts) :: fapar_tree          ! tree-level fAPAR based on LAI within the crown
+    real, allocatable :: fapar_tree(:)                     ! tree-level fAPAR based on LAI within the crown
     real, dimension(nlayers_max-1) :: fapar_layer
-
-    integer:: i, layer=0
+    real, parameter :: kappa = 0.5                         ! light extinction coefficient of crown layers
+    real, parameter :: f_gap = 0.1
 
     ! local variables used for P-model part
-    real :: tk, kphio_temp
-    real, save :: co2_memory
-    real, save :: vpd_memory
-    real, save :: temp_memory
-    real, save :: patm_memory
-    real, dimension(nlayers_max), save :: par_memory
+    real :: kphio_temp
     type(outtype_pmodel) :: out_pmodel      ! list of P-model output variables
 
+    allocate(fapar_tree(vegn%n_cohorts())) ! no need to deallocate
+    fapar_layer(:) = 0.0
+    LAIlayer(:) = 0.0
+
     !-----------------------------------------------------------
     ! Canopy light absorption
     !-----------------------------------------------------------
     ! ! Calculate kappa according to sun zenith angle 
-    ! kappa = cc%extinct/max(cosz,0.01)
-    
-    ! Use constant light extinction coefficient
-    kappa = 0.5         !cc%extinct
+    ! kappa = extinct/max(cosz,0.01)
 
     ! Sum leaf area over cohorts in each crown layer -> LAIlayer(layer)
-    f_gap = 0.1 ! 0.1
-    accuCAI = 0.0
-    LAIlayer(:) = 0.0
-    fapar_layer(:) = 0.0
-    do i = 1, vegn%n_cohorts
-      cc => vegn%cohorts(i)
-      layer = Max(1, Min(cc%layer, nlayers_max))
-      LAIlayer(layer) = LAIlayer(layer) + cc%leafarea * cc%nindivs / (1.0 - f_gap)
-      fapar_tree(i) = 1.0 - exp(-kappa * cc%leafarea / cc%crownarea)   ! at individual-level: cc%leafarea represents leaf area index within the crown
-      fapar_layer(layer) = fapar_layer(layer) + fapar_tree(i) * cc%crownarea * cc%nindivs
-    enddo
+    i = 0
+    it => vegn%cohorts()
+    do while (associated(it))
+      cc => it%cohort
+      i = i + 1
+      LAIlayer(cc%layer) = LAIlayer(cc%layer) + cc%leafarea() * cc%density / (1.0 - f_gap)
+      fapar_tree(i) = 1.0 - exp(-kappa * cc%leafarea() / cc%crownarea())   ! at individual-level: cc%leafarea() represents leaf area index within the crown
+      fapar_layer(cc%layer) = fapar_layer(cc%layer) + fapar_tree(i) * cc%crownarea() * cc%density
+      it => it%next()
+    end do
 
     ! Get light received at each crown layer as a fraction of top-of-canopy -> f_light(layer) 
     f_light(:) = 0.0
@@ -125,7 +122,7 @@ contains
     enddo
 
 
-    if (trim(myinterface%params_siml%method_photosynth) == "gs_leuning") then
+    if (trim(inputs%params_siml%method_photosynth) == "gs_leuning") then
       !===========================================================
       ! Original BiomeE-Allocation
       !-----------------------------------------------------------
@@ -135,122 +132,107 @@ contains
       ! Photosynthesis
       accuCAI = 0.0
 
-      cohortsloop_leuning: do i = 1, vegn%n_cohorts
+      it => vegn%cohorts()
+      do while (associated(it))
 
-        cc => vegn%cohorts(i)
-        associate ( sp => myinterface%params_species(cc%species) )
+        cc => it%cohort
+        associate ( sp => cc%sp() )
 
         if (cc%status == LEAF_ON) then   !.and. cc%lai > 0.1
 
           ! Convert forcing data
-          layer    = Max (1, Min(cc%layer, nlayers_max))
-          rad_top  = f_light(layer) * forcing%radiation ! downward radiation at the top of the canopy, W/m2
+          rad_top  = f_light(cc%layer) * forcing%radiation ! downward radiation at the top of the canopy, W/m2
 
           !===============================
           ! ORIGINAL
           !===============================
-          rad_net  = f_light(layer) * forcing%radiation * 0.9 ! net radiation absorbed by the canopy, W/m2
+          rad_net  = f_light(cc%layer) * forcing%radiation * 0.9 ! net radiation absorbed by the canopy, W/m2
           p_surf   = forcing%P_air  ! Pa
-          TairK    = forcing%Tair ! K
-          Tair     = forcing%Tair - 273.16 ! degC
-          cana_q   = (calc_esat(Tair) * forcing%RH * h2o_molmass) / (p_surf * kMa)  ! air specific humidity, kg/kg
+          TairK    = forcing%TairK ! K
+          TairC    = forcing%TairC ! deg C
+          cana_q   = (calc_esat(TairC) * forcing%RH * h2o_molmass) / (p_surf * kMa)  ! air specific humidity, kg/kg
           cana_co2 = forcing%CO2 ! co2 concentration in canopy air space, mol CO2/mol dry air
 
           ! recalculate the water supply to mol H20 per m2 of leaf per second
-          water_supply = cc%W_supply / (cc%leafarea * myinterface%step_seconds * h2o_molmass * 1e-3) ! mol m-2 leafarea s-1
+          water_supply = cc%W_supply() / (cc%leafarea() * inputs%step_seconds * h2o_molmass * 1e-3) ! mol m-2 leafarea s-1
 
           !call get_vegn_wet_frac (cohort, fw=fw, fs=fs)
           fw = 0.0
           fs = 0.0
 
-          call gs_leuning(rad_top, rad_net, TairK, cana_q, cc%lai, &
+          call gs_leuning(rad_top, rad_net, TairK, cana_q, cc%lai(), &
             p_surf, water_supply, cc%species, sp%pt, &
-            cana_co2, cc%extinct, fs+fw, &
+            cana_co2, extinct, fs+fw, &
             psyn, resp, w_scale2, transp )
 
-          !===============================
-          ! XXX Experiment: increasing net photosynthesis 15% and 30%
-          !===============================
-          ! if (myinterface%steering%year>myinterface%params_siml%spinupyears) then
-          !   psyn = psyn * 1.30
-          !   resp = resp * 1.30
-          ! endif
-
           ! store the calculated photosynthesis, photorespiration, and transpiration for future use in growth
-          cc%An_op   = psyn   ! molC s-1 m-2 of leaves ! net photosynthesis, mol C/(m2 of leaves s)
-          cc%An_cl   = -resp  ! molC s-1 m-2 of leaves
-          cc%w_scale = w_scale2
-          cc%transp  = transp * h2o_molmass * 1e-3 * cc%leafarea * myinterface%step_seconds      ! Transpiration (kgH2O/(tree step), Weng, 2017-10-16
-          cc%resl    = -resp         * c_molmass * 1e-3 * cc%leafarea * myinterface%step_seconds ! kgC tree-1 step-1
-          cc%gpp     = (psyn - resp) * c_molmass * 1e-3 * cc%leafarea * myinterface%step_seconds ! kgC step-1 tree-1
-
-          else
-
-          ! no leaves means no photosynthesis and no stomatal conductance either
-            cc%An_op   = 0.0
-            cc%An_cl   = 0.0
-            cc%gpp     = 0.0
-            cc%transp  = 0.0
-            cc%w_scale = -9999
+          cc%fast_fluxes%trsp = transp * h2o_molmass * 1e-3 * cc%leafarea() * inputs%step_seconds      ! Transpiration (kgH2O/(tree step), Weng, 2017-10-16
+          cc%resl = -resp * c_molmass * 1e-3 * cc%leafarea() * inputs%step_seconds ! kgC tree-1 step-1
+          cc%fast_fluxes%gpp = (psyn - resp) * c_molmass * 1e-3 * cc%leafarea() * inputs%step_seconds ! kgC step-1 tree-1
 
+          ! Calculate isotopic 13C signature of recent assimilates, given atmospheric 13C signature and discrimination (bigdelta)
+          ! Discrimination is calculated as a function of ci:ca (chi) in gpp().
+          cc%fast_fluxes%bigdelta = 20.0 ! permil, hold fixed for demo implementation of d13C in method_photosynth == "gs_leuning"
+          cc%fast_fluxes%d13c_gpp = &
+            ( forcing%d13c_atm - cc%fast_fluxes%bigdelta ) / &
+            ( cc%fast_fluxes%bigdelta / 1000.0 + 1.0 ) !(e.g. eq 2; Brüggemann, 10.5194/bg-8-3457-2011)
           endif
         end associate
-      enddo cohortsloop_leuning
 
-    else if (trim(myinterface%params_siml%method_photosynth) == "pmodel") then
+        it => it%next()
+      end do
+
+    else if (trim(inputs%params_siml%method_photosynth) == "pmodel") then
       !===========================================================
       ! P-model
       !-----------------------------------------------------------
       ! Calculate environmental conditions with memory, time scale 
       ! relevant for Rubisco turnover
       !----------------------------------------------------------------
-      if (init) then
-        co2_memory  = forcing%CO2 * 1.0e6
-        temp_memory = (forcing%Tair - kTkelvin)
-        vpd_memory  = forcing%vpd
-        patm_memory = forcing%P_air
-        par_memory = -1.0 ! We initialize par_memory to a dummy value used to detect the need for initialization,
-        ! as the initialization process using init flags is error prone given the dunmaic the adjuction of layers.
-      end if 
-      
-      co2_memory  = dampen_variability( forcing%CO2 * 1.0e6,        params_gpp%tau_acclim, co2_memory )
-      temp_memory = dampen_variability( (forcing%Tair - kTkelvin),  params_gpp%tau_acclim, temp_memory)
-      vpd_memory  = dampen_variability( forcing%vpd,                params_gpp%tau_acclim, vpd_memory )
-      patm_memory = dampen_variability( forcing%P_air,              params_gpp%tau_acclim, patm_memory )
+      if (.not. vegn%dampended_forcing%initialized) then
+        vegn%dampended_forcing%co2  = forcing%CO2 * 1.0e6
+        vegn%dampended_forcing%temp = (forcing%TairC)
+        vegn%dampended_forcing%vpd  = forcing%vpd
+        vegn%dampended_forcing%patm = forcing%P_air
+        vegn%dampended_forcing%par = forcing%radiation
+        vegn%dampended_forcing%initialized = .True.
+      else
+        vegn%dampended_forcing%co2  = dampen_variability( forcing%CO2 * 1.0e6,        params_gpp%tau_acclim, &
+                vegn%dampended_forcing%co2 )
+        vegn%dampended_forcing%temp = dampen_variability( (forcing%TairC),  params_gpp%tau_acclim, &
+                vegn%dampended_forcing%temp)
+        vegn%dampended_forcing%vpd  = dampen_variability( forcing%vpd,                &
+                params_gpp%tau_acclim, vegn%dampended_forcing%vpd )
+        vegn%dampended_forcing%patm = dampen_variability( forcing%P_air,              &
+                params_gpp%tau_acclim, vegn%dampended_forcing%patm )
+        vegn%dampended_forcing%par = dampen_variability( forcing%radiation,              &
+                params_gpp%tau_acclim, vegn%dampended_forcing%par )
+      end if
 
-      tk = forcing%Tair + kTkelvin
+      !----------------------------------------------------------------
+      ! Instantaneous temperature effect on quantum yield efficiency
+      !----------------------------------------------------------------
+      kphio_temp = calc_kphio_temp( (forcing%TairC), &
+              .false., &    ! no C4
+              params_gpp%kphio, &
+              params_gpp%kphio_par_a, &
+              params_gpp%kphio_par_b )
 
       !----------------------------------------------------------------
       ! Photosynthesis for each cohort
       !----------------------------------------------------------------
-      cohortsloop_pmodel: do i = 1, vegn%n_cohorts
+      i = 0
+      it => vegn%cohorts()
+      do while (associated(it))
 
-        cc => vegn%cohorts(i)
-        associate ( sp => myinterface%params_species(cc%species) )
-
-        ! get canopy layer of this cohort
-        layer = max(1, min(cc%layer, nlayers_max))
-
-        !----------------------------------------------------------------
-        ! Instantaneous temperature effect on quantum yield efficiency
-        !----------------------------------------------------------------
-        kphio_temp = calc_kphio_temp( (forcing%Tair - kTkelvin), &
-                .false., &    ! no C4
-                params_gpp%kphio, &
-                params_gpp%kphio_par_a, &
-                params_gpp%kphio_par_b )
-
-        ! photosynthetically active radiation level at this layer
-        par = f_light(layer) * forcing%radiation * kfFEC * 1.0e-6
-        ! slowly varying light conditions per layer, relevant for acclimation (P-model quantities)
-        if (par_memory(layer) <= -1.0) then
-          par_memory(layer) = par
-        else
-          par_memory(layer) = dampen_variability(par, params_gpp%tau_acclim, par_memory(layer))
-        end if
+        cc => it%cohort
+        i = i + 1
 
         if (cc%status == LEAF_ON) then
 
+          ! photosynthetically active radiation level at this layer
+          par = f_light(cc%layer) * vegn%dampended_forcing%par * kfFEC * 1.0e-6
+
           !----------------------------------------------------------------
           ! P-model call for C3 plants to get a list of variables that are 
           ! acclimated to slowly varying conditions
@@ -259,42 +241,33 @@ contains
                                 kphio          = kphio_temp, &
                                 beta           = params_gpp%beta, &
                                 kc_jmax        = params_gpp%kc_jmax, &
-                                ppfd           = par_memory(layer), &
-                                co2            = co2_memory, &
-                                tc             = temp_memory, &
-                                vpd            = vpd_memory, &
-                                patm           = patm_memory, &
+                                ppfd           = par, &
+                                co2            = vegn%dampended_forcing%co2, &
+                                tc             = vegn%dampended_forcing%temp, &
+                                vpd            = vegn%dampended_forcing%vpd, &
+                                patm           = vegn%dampended_forcing%patm, &
+                                tc_home        = inputs%site_info%tc_home, &
                                 c4             = .false., &
                                 method_optci   = "prentice14", &
                                 method_jmaxlim = "wang17" &
                                 )
 
-          ! irrelevant variables for this setup  
-          cc%An_op   = 0.0
-          cc%An_cl   = 0.0
-          cc%transp  = 0.0
-          cc%w_scale = -9999            
-
           ! quantities per tree and cumulated over seconds in time step (kgC step-1 tree-1 )
-          cc%gpp = par * fapar_tree(i) * out_pmodel%lue * cc%crownarea * myinterface%step_seconds * 1.0e-3
-          cc%resl = fapar_tree(i) * out_pmodel%vcmax25 * params_gpp%rd_to_vcmax * calc_ftemp_inst_rd( forcing%Tair - kTkelvin ) &
-            * cc%crownarea * myinterface%step_seconds * c_molmass * 1.0e-3
+          cc%fast_fluxes%gpp = par * fapar_tree(i) * out_pmodel%lue * cc%crownarea() * inputs%step_seconds * 1.0e-3
+          cc%resl = fapar_tree(i) * out_pmodel%vcmax25 * params_gpp%rd_to_vcmax * calc_ftemp_inst_rd( forcing%TairC ) &
+            * cc%crownarea() * inputs%step_seconds * c_molmass * 1.0e-3
 
-        else
-
-          ! no leaves means no photosynthesis and no stomatal conductance either
-          cc%An_op   = 0.0
-          cc%An_cl   = 0.0
-          cc%transp  = 0.0
-          cc%w_scale = -9999
-          cc%resl    = 0.0
-          cc%gpp     = 0.0
+          ! Calculate isotopic 13C signature of recent assimilates, given atmospheric 13C signature and discrimination (bigdelta)
+          ! Discrimination is calculated as a function of ci:ca (chi) in gpp().
+          cc%fast_fluxes%bigdelta = calc_bigdelta( out_pmodel%chi, out_pmodel%ca, out_pmodel%gammastar )
+          cc%fast_fluxes%d13c_gpp = &
+            ( forcing%d13c_atm - cc%fast_fluxes%bigdelta ) / &
+            ( cc%fast_fluxes%bigdelta / 1000.0 + 1.0 ) !(e.g. eq 2; Brüggemann, 10.5194/bg-8-3457-2011)
 
         endif
 
-        end associate
-
-      end do cohortsloop_pmodel
+        it => it%next()
+      end do
 
     end if
 
@@ -303,7 +276,7 @@ contains
 
   subroutine gs_leuning( rad_top, rad_net, tl, ea, lai, &
     p_surf, ws, species, pt, ca, kappa, leaf_wet, &
-    apot, acl,w_scale2, transp )
+    apot, acl, w_scale2, transp )
 
     ! taking from params_core (SOFUN)
     use md_params_core, only: kR, kTkelvin
@@ -311,7 +284,7 @@ contains
 
     real,    intent(in)    :: rad_top ! PAR dn on top of the canopy, w/m2
     real,    intent(in)    :: rad_net ! PAR net on top of the canopy, w/m2
-    real,    intent(in)    :: tl   ! leaf temperature, degK
+    real,    intent(in)    :: tl   ! leaf temperature, K
     real,    intent(in)    :: ea   ! specific humidity in the canopy air, kg/kg
     real,    intent(in)    :: lai  ! leaf area index
     !real,    intent(in)    :: leaf_age ! age of leaf since budburst (deciduos), days
@@ -328,7 +301,7 @@ contains
     !real,    intent(out)   :: gs   ! stomatal conductance, m/s
     real,    intent(out)   :: apot ! net photosynthesis, mol C/(m2 s)
     real,    intent(out)   :: acl  ! leaf respiration, mol C/(m2 s)
-    real,    intent(out)   :: w_scale2,transp  ! transpiration, mol H20/(m2 of leaf s)
+    real,    intent(out)   :: w_scale2, transp  ! transpiration, mol H20/(m2 of leaf s)
     
     ! local variables     
     ! photosynthesis
@@ -370,7 +343,7 @@ contains
     real :: Ed, an_w, gs_w
 
 
-    associate (spdata => myinterface%params_species)
+    associate (spdata => inputs%params_species)
 
     b = 0.01
     do1 = 0.15 ! kg/kg
@@ -556,48 +529,18 @@ contains
 
   ! end subroutine calc_solarzen
 
-
-  subroutine getpar_modl_gpp()
-    !////////////////////////////////////////////////////////////////
-    ! Subroutine reads module-specific parameters from input file.
-    !----------------------------------------------------------------
-    ! unit cost of carboxylation
-    params_gpp%beta  = 146.000000
-
-    ! Ratio of Rdark to Vcmax25, number from Atkin et al., 2015 for C3 herbaceous
-    params_gpp%rd_to_vcmax  = 0.01400000
-
-    ! Apply identical temperature ramp parameter for all PFTs
-    params_gpp%tau_acclim     = 30.0
-    params_gpp%soilm_thetastar= 0.6 * 250
-    params_gpp%soilm_betao    = 0.0
-
-    ! Jmax cost ratio
-    params_gpp%kc_jmax  = 0.41
-
-    ! quantum yield efficiency at optimal temperature, phi_0 (Stocker et al., 2020 GMD Eq. 10)
-    params_gpp%kphio = 0.05
-
-    ! shape parameter of temperature-dependency of quantum yield efficiency
-    params_gpp%kphio_par_a = 0.0
-
-    ! optimal temperature of quantum yield efficiency
-    params_gpp%kphio_par_b = 25.0
-
-  end subroutine getpar_modl_gpp
-
   function qscomp(T, p) result(qsat)
     !--------Output
     real :: qsat ! Output type: saturated specific humidity, kg/kg
     !--------Inputs
-    real :: T    ! temperature, degK
+    real :: T    ! temperature, K
     real :: p    ! pressure, Pa
     !--------local var
     real :: myesat ! sat. water vapor pressure
-    real :: Temp ! degC
+    real :: Temp ! deg C
 
     ! calculate saturated specific humidity
-    Temp = T - 273.16 ! degC
+    Temp = T - 273.16 ! deg C
     myesat=MIN(610.78*exp(17.27*Temp/(Temp+237.3)), p) ! Pa
     qsat = 0.622*myesat /(p - 0.378*myesat )
 
