@@ -11,7 +11,7 @@ module md_gpp_pmodel
   use md_sofunutils, only: radians
   use md_grid, only: gridtype
   use md_photosynth, only: pmodel, zero_pmodel, outtype_pmodel, calc_ftemp_inst_vcmax, calc_ftemp_inst_jmax, &
-    calc_ftemp_inst_rd, calc_kphio_temp, calc_soilmstress
+    calc_ftemp_inst_rd, calc_kphio_temp, calc_soilmstress, calc_bigdelta
 
   implicit none
 
@@ -44,7 +44,7 @@ module md_gpp_pmodel
 
 contains
 
-  subroutine gpp( tile, tile_fluxes, co2, climate, grid, init, in_ppfd)
+  subroutine gpp( tile, tile_fluxes, co2, climate, grid, init, in_ppfd, tc_home)
     !//////////////////////////////////////////////////////////////////
     ! Wrapper function to call to P-model. 
     ! Calculates meteorological conditions with memory based on daily
@@ -63,6 +63,7 @@ contains
     type(gridtype)      :: grid
     logical, intent(in) :: init                              ! is true on the very first simulation day (first subroutine call of each gridcell)
     logical, intent(in) :: in_ppfd                           ! whether to use PPFD from forcing or from SPLASH output
+    real, intent(in)    :: tc_home                           ! long-term mean max temp of the warmest month (deg C)
 
     ! local variables
     type(outtype_pmodel) :: out_pmodel              ! list of P-model output variables
@@ -151,6 +152,7 @@ contains
                               tc             = temp_memory, &
                               vpd            = vpd_memory, &
                               patm           = patm_memory, &
+                              tc_home        = tc_home, &
                               c4             = params_pft_plant(pft)%c4, &
                               method_optci   = "prentice14", &
                               method_jmaxlim = "wang17" &
@@ -183,11 +185,11 @@ contains
       ! but not too dangerous...
       !----------------------------------------------------------------
       if( in_ppfd ) then
-        ! Take input daily PPFD (in mol/m^2)
+        ! Take input daily PPFD (dppfd in mol m-2 s-1)
         tile_fluxes(lu)%plant(pft)%dgpp = tile(lu)%plant(pft)%fpc_grid * tile(lu)%canopy%fapar &
           * climate%dppfd * myinterface%params_siml%secs_per_tstep * out_pmodel%lue * soilmstress
       else
-        ! Take daily PPFD generated by SPLASH (in mol/m^2/d)
+        ! Take daily PPFD generated by SPLASH (ppfd_splash in mol m-2 d-1)
         tile_fluxes(lu)%plant(pft)%dgpp = tile(lu)%plant(pft)%fpc_grid * tile(lu)%canopy%fapar &
           * tile_fluxes(lu)%canopy%ppfd_splash * out_pmodel%lue * soilmstress
       end if
@@ -209,178 +211,39 @@ contains
       tile_fluxes(lu)%plant(pft)%iwue    = out_pmodel%iwue
 
       ! quantities with instantaneous temperature response
-      tile_fluxes(lu)%plant(pft)%vcmax = calc_ftemp_inst_vcmax( climate%dtemp, climate%dtemp, tcref = 25.0 ) * out_pmodel%vcmax25
-      tile_fluxes(lu)%plant(pft)%jmax  = calc_ftemp_inst_jmax(  climate%dtemp, climate%dtemp, tcref = 25.0 ) * out_pmodel%jmax25
+      tile_fluxes(lu)%plant(pft)%vcmax = calc_ftemp_inst_vcmax( &
+          tc_leaf   = climate%dtemp, &
+          tc_growth = temp_memory, &
+          ! no tc_home needed for calc_ftemp_inst_vcmax
+          tc_ref    = 25.0 ) * out_pmodel%vcmax25
+
+      tile_fluxes(lu)%plant(pft)%jmax = calc_ftemp_inst_jmax( &
+          tc_leaf   = climate%dtemp, &
+          tc_growth = temp_memory, &
+          tc_home   = tc_home, &
+          tc_ref    = 25.0 ) * out_pmodel%jmax25
 
       !----------------------------------------------------------------
       ! Stomatal conductance
       !----------------------------------------------------------------
       tile_fluxes(lu)%plant(pft)%gs_accl = out_pmodel%gs_setpoint
 
+      !----------------------------------------------------------------
+      ! C isotope fractionation
+      !----------------------------------------------------------------
+      tile_fluxes(lu)%plant(pft)%bigdelta = calc_bigdelta( out_pmodel%chi, out_pmodel%ca, out_pmodel%gammastar )
+
+      ! Calculate isotopic 13C signature of recent assimilates, given atmospheric 13C signature and discrimination (bigdelta)
+      ! Discrimination is calculated as a function of ci:ca (chi) in gpp().
+      tile_fluxes(lu)%plant(pft)%d13c_gpp = &
+        ( climate%d13c_atm - tile_fluxes(lu)%plant(pft)%bigdelta ) / & 
+        ( tile_fluxes(lu)%plant(pft)%bigdelta / 1000.0 + 1.0 ) !(e.g. eq 2; Brüggemann, 10.5194/bg-8-3457-2011)
+
     end do pftloop
 
   end subroutine gpp
 
 
-
-  ! function calc_dgpp( fapar, fpc_grid, dppfd, lue, kphio_temp, soilmstress ) result( my_dgpp )
-  !   !//////////////////////////////////////////////////////////////////
-  !   ! Calculates daily GPP given mean daily light use efficiency following
-  !   ! a simple light use efficie model approach.
-  !   !------------------------------------------------------------------
-  !   ! arguments
-  !   real, intent(in) :: fapar       ! fraction of absorbed photosynthetically active radiation (unitless)
-  !   real, intent(in) :: fpc_grid    ! foliar projective cover, used for dividing grid cell area (unitless)
-  !   real, intent(in) :: dppfd       ! daily total photon flux density (mol m-2)
-  !   real, intent(in) :: lue         ! light use efficiency (g CO2 mol-1)
-  !   real, intent(in) :: kphio_temp  ! air temperature (deg C)
-  !   real, intent(in) :: soilmstress ! soil moisture stress factor (unitless)
-
-  !   ! function return variable
-  !   real :: my_dgpp                 ! Daily total gross primary productivity (gC m-2 d-1)
-
-  !   ! GPP is light use efficiency multiplied by absorbed light and soil moisture stress function
-  !   my_dgpp = fapar * fpc_grid * dppfd * soilmstress * lue * kphio_temp
-
-  ! end function calc_dgpp
-
-
-  ! function calc_dassim( dgpp, daylength ) result( my_dassim )
-  !   !//////////////////////////////////////////////////////////////////
-  !   ! Calculates assimilation rate, mean over daylight hours.
-  !   ! Use *_unitfapar to get something representative of top-of-canopy.
-  !   !------------------------------------------------------------------
-  !   ! arguments
-  !   real, intent(in) :: dgpp            ! daily total GPP (g CO2 m-2 d-1)
-  !   real, intent(in) :: daylength       ! day length (h)
-
-  !   ! function return variable
-  !   real :: my_dassim                   ! canopy mean assimilation rate, mean over daylight hours (mol CO2 m-2 s-1)
-
-  !   ! Assimilation rate, average over daylight hours
-  !   if (daylength>0.0) then
-  !     my_dassim = dgpp / ( 60.0 * 60.0 * daylength * c_molmass )
-  !   else
-  !     my_dassim = 0.0
-  !   end if
-
-  ! end function calc_dassim
-
-
-  ! function calc_dgs( dassim, vpd, ca, gammastar, xi ) result( dgs )
-  !   !//////////////////////////////////////////////////////////////////
-  !   ! Calculates leaf-level stomatal conductance to CO2.
-  !   ! This uses instantaneous VPD and is therefore not calculated inside
-  !   ! the P-model function. The slope parameter 'xi' is representative
-  !   ! for the acclimated response.
-  !   !------------------------------------------------------------------
-  !   ! arguments
-  !   real, intent(in) :: dassim          ! daily mean assimilation rate (mol CO2 m-2 s-1)
-  !   real, intent(in) :: vpd             ! vapour pressure deficit (Pa)
-  !   real, intent(in) :: ca              ! ambient CO2 partial pressure (Pa)
-  !   real, intent(in) :: gammastar       ! CO2 compensation point (Pa)
-  !   real, intent(in) :: xi              ! slope parameter of stomatal response derived from P-model optimality, corresponding to sqrt(beta*(K+gammastar)/(1.6*etastar)) (Pa)
-  !   ! real, intent(in) :: dgs_unitiabs    ! stomatal conductance per unit absorbed light (mol CO2 Pa-1 m-2 s-1 / mol light)
-
-  !   ! function return variable
-  !   real :: dgs                         ! leaf-level stomatal conductance to H2O, mean over daylight hours ( mol CO2 Pa-1 m-2 s-1 )
-
-  !   ! Leaf-level assimilation rate, average over daylight hours
-  !   ! dgs = dassim * dgs_unitiabs
-  !   dgs = (1.0 + xi / sqrt(vpd)) * dassim / (ca - gammastar)
-  !   ! print*,'instantaneous gs: ', dgs 
-    
-  ! end function calc_dgs
-
-
-  ! function calc_drd( fapar, fpc_grid, dppfd, rd_unitiabs, kphio_temp, soilmstress ) result( my_drd )
-  !   !//////////////////////////////////////////////////////////////////
-  !   ! Calculates daily total dark respiration (Rd) based on monthly mean 
-  !   ! PPFD (assumes acclimation on a monthly time scale).
-  !   ! Not described in Stocker et al., XXX.
-  !   !------------------------------------------------------------------
-  !   ! arguments
-  !   real, intent(in) :: fapar           ! fraction of absorbed photosynthetically active radiation
-  !   real, intent(in) :: fpc_grid        ! foliar projective cover
-  !   real, intent(in) :: dppfd           ! daily total photon flux density (mol m-2)
-  !   real, intent(in) :: rd_unitiabs
-  !   real, intent(in) :: kphio_temp      ! this day's air temperature, deg C
-  !   real, intent(in) :: soilmstress     ! soil moisture stress factor
-
-  !   ! function return variable
-  !   real :: my_drd
-
-  !   ! Dark respiration takes place during night and day (24 hours)
-  !   my_drd = fapar * fpc_grid * dppfd * soilmstress * rd_unitiabs * kphio_temp * c_molmass
-
-  ! end function calc_drd
-
-
-  ! function calc_dtransp( fapar, acrown, dppfd, transp_unitiabs, kphio_temp, soilmstress ) result( my_dtransp )
-  !   !//////////////////////////////////////////////////////////////////
-  !   ! Calculates daily transpiration. 
-  !   ! Exploratory only.
-  !   ! Not described in Stocker et al., XXX.
-  !   !------------------------------------------------------------------
-  !   ! arguments
-  !   real, intent(in) :: fapar
-  !   real, intent(in) :: acrown
-  !   real, intent(in) :: dppfd              ! daily total photon flux density, mol m-2
-  !   real, intent(in) :: transp_unitiabs
-  !   real, intent(in) :: kphio_temp              ! this day's air temperature
-  !   real, intent(in) :: soilmstress        ! soil moisture stress factor
-
-  !   ! function return variable
-  !   real :: my_dtransp
-
-  !   ! GPP is light use efficiency multiplied by absorbed light and C-P-alpha
-  !   my_dtransp = fapar * acrown * dppfd * soilmstress * transp_unitiabs * kphio_temp * h2o_molmass
-
-  ! end function calc_dtransp
-
-
-  ! function calc_vcmax_canop( fapar, vcmax_unitiabs, meanmppfd ) result( my_vcmax )
-  !   !//////////////////////////////////////////////////////////////////
-  !   ! Calculates canopy-level summed carboxylation capacity (Vcmax). To get
-  !   ! value per unit leaf area, divide by LAI.
-  !   ! Not described in Stocker et al., XXX.
-  !   !------------------------------------------------------------------
-  !   ! arguments
-  !   real, intent(in) :: fapar
-  !   real, intent(in) :: vcmax_unitiabs
-  !   real, intent(in) :: meanmppfd
-
-  !   ! function return variable
-  !   real :: my_vcmax    ! canopy-level Vcmax [gCO2/m2-ground/s]
-
-  !   ! Calculate leafy-scale Rubisco-N as a function of LAI and current LUE
-  !   my_vcmax = fapar * meanmppfd * vcmax_unitiabs
-
-  ! end function calc_vcmax_canop
-
-
-  ! function calc_g_canopy( g_stomata, lai, tk ) result( g_canopy )
-  !   !/////////////////////////////////////////////////////////////////////////
-  !   ! Calculates canopy conductance, proportional to the leaf area index.
-  !   ! Since g_stomata is taken here from the photosynthesis module, we don't 
-  !   ! use Eq. 8 in Zhang et al. (2017).
-  !   !-------------------------------------------------------------------------
-  !   use md_params_core, only: kR
-
-  !   ! arguments
-  !   real, intent(in) :: g_stomata      ! stomatal conductance (mol CO2 Pa-1 m-2 s-1)
-  !   real, intent(in) :: lai            ! leaf area index, single-sided (unitless)
-  !   real, intent(in) :: tk             ! (leaf) temperature (K)
-
-  !   ! function return variable
-  !   real :: g_canopy    ! canopy conductance (m s-1)
-
-  !   ! canopy conductance scales with LAI. Including unit conversion to m s-1.
-  !   g_canopy = 1.6 * g_stomata * kR * tk * lai
-
-  ! end function calc_g_canopy
-
-
   ! function calc_climate_acclimation( climate, grid, method ) result( climate_acclimation )
   !   !//////////////////////////////////////////////////////////////////
   !   ! Convert daily mean environmental conditions to conditions to
@@ -472,6 +335,7 @@ contains
 
   ! end function calc_climate_acclimation  
 
+
   subroutine getpar_modl_gpp()
     !////////////////////////////////////////////////////////////////
     ! Subroutine reads module-specific parameters from input file.
