@@ -9,7 +9,7 @@ module md_interface_pmodel
   ! use md_params_soil_pmodel, only: paramtype_soil
   use md_params_siml_pmodel, only: paramstype_siml_pmodel
   use md_params_core, only: nlayers_soil, ndayyear, npft, outtype_steering
-  use md_grid, only: gridtype !, domaininfo_type
+  use md_grid, only: gridtype
 
   implicit none
 
@@ -34,10 +34,10 @@ module md_interface_pmodel
     real                                    :: pco2
     type(gridtype)                          :: grid
     real                                    :: whc_prescr
+    real                                    :: tc_home
     type(climate_type), dimension(ndayyear) :: climate
     type(vegcover_type), dimension(ndayyear):: vegcover
-    ! type(domaininfo_type)                 :: domaininfo
-    type(outtype_steering)                  :: steering
+    type(outtype_steering)                  :: steering_state
     type(paramstype_siml_pmodel)            :: params_siml
     real, dimension(npft)                   :: fpc_grid        ! allocatable because we don't know number of PFTs a priori
     type(paramstype_calib)                  :: params_calib    ! calibratable parameters
@@ -70,6 +70,8 @@ module md_interface_pmodel
     real, dimension(ndayyear) :: wcont
     real, dimension(ndayyear) :: snow
     real, dimension(ndayyear) :: cond
+    real, dimension(ndayyear) :: cleaf
+    real, dimension(ndayyear) :: cleafd13c
   end type outtype_biosphere
 
 end module md_interface_pmodel
