@@ -5,7 +5,6 @@ module md_params_core
   !----------------------------------------------------------------
   implicit none
 
-  integer :: ntstepsyear                         ! 365 when daily
   integer, parameter :: ndayyear = 365           ! number of days in a year
   integer, parameter :: nhoursyear = 8760        ! number of days in a year
   integer, parameter :: nmonth = 12              ! number of months in a year
@@ -15,13 +14,6 @@ module md_params_core
 
   ! From LM3-PPA
   integer, parameter :: nlayers_soil = 3         ! number of soil layers
-  integer, parameter :: out_max_cohorts = 50     ! maximum number of cohorts
-
-  integer, parameter :: nvars_hourly_tile = 15
-  integer, parameter :: nvars_daily_tile = 35
-  integer, parameter :: nvars_daily_cohorts = 27
-  integer, parameter :: nvars_annual_tile = 59
-  integer, parameter :: nvars_annual_cohorts = 34
 
   !===== Physical constants
   real, parameter :: mol_CO2  = 44.00995e-3           ! molar mass of CO2,kg
@@ -32,7 +24,7 @@ module md_params_core
   integer, parameter :: maxgrid = 1              ! number of spatial gridcells (dummy dimension for later code extension)
   integer, parameter :: nbucket = 2              ! number of buckets for soil water model
   integer, parameter :: npft = 1                 ! number of PFTs !3
-  integer, parameter :: nlu = 1                  ! number of land units (tiles)
+  integer, parameter :: nlu = 1                  ! number of land units (tiles) !! ATTENTION: only for pmodel
   integer, parameter :: lunat = 1                ! ID of natural land unit
   integer, parameter :: lucrop = 2               ! ID of crop land unit
 
@@ -66,36 +58,37 @@ module md_params_core
   real, parameter :: dummy = -9999.0             ! arbitrary dummy value
 
   type outtype_steering
-    integer :: year
-    integer :: climateyear     ! year AD for which climate is read in (recycling during spinup or when climate is held const.)
-    integer :: climateyear_idx ! year index for which climate is read in.
-    integer :: forcingyear     ! year AD for which forcings are read in (=firstyeartrend during spinup)
-    integer :: forcingyear_idx ! year index for which forcings are read in (=1 during spinup)
-    integer :: outyear         ! year AD written to output
-    logical :: spinup          ! is true during spinup
-    logical :: init            ! is true in first simulation year
-    logical :: finalize        ! is true in the last simulation year
-    logical :: do_soilequil    ! true in year of analytical soil equilibration (during spinup)
-    logical :: average_soil    ! true in years before analytical soil equilibration, when average in and out are taken
-    logical :: project_nmin    ! true in all years before analytical soil equilibration, when projected soil N mineralisation is used
-    logical :: dofree_alloc    ! true if allocation is not fixed by 'frac_leaf'
-    logical :: add_ninorg      ! true in the first few years to get it started
+    integer :: year = 0           ! current simulation year
+    integer :: climateyear        ! year AD for which climate is read in (recycling during spinup or when climate is held const.)
+    integer :: climateyear_idx    ! year index for which climate is read in.
+    integer :: forcingyear        ! year AD for which forcings are read in (=firstyeartrend during spinup)
+    integer :: forcingyear_idx    ! year index for which forcings are read in (=1 during spinup)
+    integer :: outyear            ! year AD written to output
+    logical :: spinup             ! is true during spinup
+    logical :: init     = .true.  ! is true in first simulation year
+    logical :: finalize = .false. ! is true in the last simulation year
+    logical :: daily_reporting    ! whether daily reporting should be done in the current year
+    integer :: daily_report_idx   ! start_idx for output_annual_cohorts of current year
+    logical :: cohort_reporting   ! whether cohort level reporting should be done in the current year
+    integer :: cohort_report_idx  ! start_idx for output_daily_tile of current year
+    ! Note: climateyear_idx == forcingyear_idx during transient phase. During spinup however, climateyear cycles, while forcing year is constant (= 1).
   end type outtype_steering
 
   type steering_parameters
 
-    integer :: spinupyears     ! number of spinup years
-    integer :: nyeartrend      ! number of transient years
-    integer :: firstyeartrend  ! year AD of first transient year
-    integer :: recycle         ! length of standard recycling period
-    logical :: do_spinup       ! whether this simulation does spinup
-    integer :: runyears        ! number of years of entire simulation (spinup+transient)
+    integer :: spinupyears      ! number of spinup years
+    integer :: nyeartrend       ! number of transient years
+    integer :: firstyeartrend   ! year AD of first transient year
+    integer :: recycle          ! length of standard recycling period
+    logical :: do_spinup        ! whether this simulation does spinup
+    integer :: runyears         ! number of years of entire simulation (spinup+transient)
+    logical :: do_daily_reporting ! whether this simulation reports daily values
 
   end type steering_parameters
 
 contains
 
-  function get_steering( year, steering ) result( out_steering )
+  pure function get_steering( year, steering_input ) result( curr_year_steering_state )
     !////////////////////////////////////////////////////////////////
     ! Gets variables used for steering simulation for each
     ! simulation year (setting booleans for opening files, doing
@@ -104,101 +97,72 @@ contains
 
     ! arguments
     integer, intent(in) :: year ! simulation year, starts counting from 1, starting at the beginning of spinup
-    type( steering_parameters ), intent(in) :: steering
+    type(steering_parameters), intent(in) :: steering_input
 
     ! function return variable
-    type( outtype_steering ) :: out_steering
+    type(outtype_steering) :: curr_year_steering_state
 
     ! local variables
     integer :: cycleyear
 
-    integer, parameter :: spinupyr_soilequil_1 = 600   ! year of analytical soil equilibration, based on mean litter -> soil input flux
-    integer, parameter :: spinupyr_soilequil_2 = 1200  ! year of analytical soil equilibration, based on mean litter -> soil input flux
-    integer, parameter :: spinup_add_ninorg    = 100   ! year until which inorganic N is added to get it started
+    curr_year_steering_state%year = year
 
-    out_steering%year = year
-
-    if (steering%do_spinup) then
-
-      if (year <= spinup_add_ninorg) then
-        out_steering%add_ninorg = .true.
-      else
-        out_steering%add_ninorg = .false.
-      end if
-
-      if (year<=steering%spinupyears) then
+    if (steering_input%do_spinup) then
+      if (year <= steering_input%spinupyears) then
         ! during spinup
-        out_steering%spinup = .true.
-        cycleyear = get_cycleyear( year, steering%spinupyears, steering%recycle )
-        out_steering%climateyear = cycleyear + steering%firstyeartrend - 1
-        out_steering%climateyear_idx = cycleyear
-        out_steering%forcingyear = steering%firstyeartrend
-        out_steering%forcingyear_idx = 1
+        cycleyear = get_cycleyear( year, steering_input%spinupyears, steering_input%recycle )
+
+        curr_year_steering_state%spinup          = .true.
+        curr_year_steering_state%climateyear     = cycleyear + steering_input%firstyeartrend - 1
+        curr_year_steering_state%climateyear_idx = cycleyear
+        curr_year_steering_state%forcingyear     = steering_input%firstyeartrend
+        curr_year_steering_state%forcingyear_idx = 1
       else
         ! during transient simulation
-        out_steering%spinup          = .false.
-        out_steering%climateyear_idx = year - steering%spinupyears
-        out_steering%climateyear     = out_steering%climateyear_idx + steering%firstyeartrend - 1
-        out_steering%forcingyear = out_steering%climateyear
-        out_steering%forcingyear_idx = out_steering%climateyear_idx
+        curr_year_steering_state%spinup          = .false.
+        curr_year_steering_state%climateyear_idx = year - steering_input%spinupyears
+        curr_year_steering_state%climateyear     = curr_year_steering_state%climateyear_idx + steering_input%firstyeartrend - 1
+        curr_year_steering_state%forcingyear     = curr_year_steering_state%climateyear
+        curr_year_steering_state%forcingyear_idx = curr_year_steering_state%climateyear_idx
       endif
-      out_steering%outyear = year + steering%firstyeartrend - steering%spinupyears - 1
-
-      if ( year > 3 ) then
-        out_steering%dofree_alloc = .true.
-      else
-        out_steering%dofree_alloc = .false.
-      end if
-
-      if ( (year==spinupyr_soilequil_1 .or. year==spinupyr_soilequil_2 ) .and. year<=steering%spinupyears) then
-        out_steering%do_soilequil = .true.
-      else
-        out_steering%do_soilequil = .false.
-      end if
-
-      if ( year<=steering%spinupyears .and. ( year > ( spinupyr_soilequil_1 - steering%recycle ) .and. &
-              year <= spinupyr_soilequil_1 .or. year > ( spinupyr_soilequil_2 - steering%recycle ) .and. &
-              year <= spinupyr_soilequil_2 ) ) then
-        out_steering%average_soil = .true.
-      else
-        out_steering%average_soil = .false.
-      end if
-
-      if ( year<=steering%spinupyears .and. year <= spinupyr_soilequil_1 ) then
-        out_steering%project_nmin = .true.
-      else
-        out_steering%project_nmin = .false.
-      end if
-
+      curr_year_steering_state%outyear           = year + steering_input%firstyeartrend - steering_input%spinupyears - 1
     else
-
-      out_steering%dofree_alloc = .false.
-      out_steering%do_soilequil = .false.
-      out_steering%average_soil = .false.
-      out_steering%project_nmin = .false.
-      out_steering%climateyear = year + steering%firstyeartrend - 1
-      out_steering%climateyear_idx = year
-      out_steering%outyear = out_steering%climateyear
-      out_steering%forcingyear = out_steering%climateyear
-      out_steering%forcingyear_idx = out_steering%climateyear_idx
-
+      curr_year_steering_state%spinup          = .false.
+      curr_year_steering_state%climateyear     = year + steering_input%firstyeartrend - 1
+      curr_year_steering_state%climateyear_idx = year
+      curr_year_steering_state%forcingyear     = curr_year_steering_state%climateyear
+      curr_year_steering_state%forcingyear_idx = curr_year_steering_state%climateyear_idx
+      curr_year_steering_state%outyear         = curr_year_steering_state%climateyear
     endif
 
+    if (curr_year_steering_state%spinup)  then
+      curr_year_steering_state%daily_reporting  = .false.
+      curr_year_steering_state%cohort_reporting = .false.
+    else
+      curr_year_steering_state%daily_reporting  = steering_input%do_daily_reporting
+      curr_year_steering_state%cohort_reporting = .true.
+    end if
+
+    ! Indices for daily and cohort output
+    ! Spinup years are not stored, which is why we offset by - spinupyears
+    curr_year_steering_state%daily_report_idx = (curr_year_steering_state%year - steering_input%spinupyears - 1) * ndayyear + 1
+    curr_year_steering_state%cohort_report_idx = curr_year_steering_state%year - steering_input%spinupyears
+        
     if (year==1) then
-      out_steering%init = .true.
+      curr_year_steering_state%init = .true.
     else
-      out_steering%init = .false.
+      curr_year_steering_state%init = .false.
     endif
 
-    if (year==steering%runyears) then
-      out_steering%finalize = .true.
+    if (year==steering_input%runyears) then
+      curr_year_steering_state%finalize = .true.
     else
-      out_steering%finalize = .false.
+      curr_year_steering_state%finalize = .false.
     end if
 
   end function get_steering
 
-  function get_cycleyear( year, spinupyears, recycle ) result( cycleyear )
+  pure function get_cycleyear( year, spinupyears, recycle ) result( cycleyear )
   !////////////////////////////////////////////////////////////////
   ! Returns cycle year for climate recycling, given number of spinup
   ! years and recycle period length, so that in the last year of
