@@ -14,7 +14,7 @@ module md_params_siml_pmodel
   !----------------------------------------------------------------
   type paramstype_siml_pmodel
 
-    type(steering_parameters) :: steering
+    type(steering_parameters) :: steering_input
     integer :: outdt           ! output periodicity
     integer :: outnt           ! number of output time steps per year
     integer :: secs_per_tstep  ! number of seconds per time step (now daily => 60 * 60 * 24)
