@@ -11,7 +11,7 @@ module md_photosynth
 
   private
   public pmodel, zero_pmodel, outtype_pmodel, calc_ftemp_inst_jmax, calc_ftemp_inst_vcmax, &
-    calc_ftemp_inst_rd, calc_kphio_temp, calc_soilmstress
+    calc_ftemp_inst_rd, calc_kphio_temp, calc_soilmstress, calc_bigdelta
 
   !----------------------------------------------------------------
   ! MODULE-SPECIFIC, PRIVATE VARIABLES
@@ -20,17 +20,17 @@ module md_photosynth
   type outtype_pmodel
     real :: gammastar           ! temperature-dependent photorespiratory compensation point (Pa)
     real :: kmm                 ! Michaelis-Menten coefficient (Pa)
-    real :: ca                  ! leaf-external (ambient) partial pressure, (Pa)
-    real :: ci                  ! leaf-internal partial pressure, (Pa)
+    real :: ca                  ! leaf-external (ambient) CO2 partial pressure, (Pa)
+    real :: ci                  ! leaf-internal CO2 partial pressure, (Pa)
     real :: chi                 ! = ci/ca, leaf-internal to ambient CO2 partial pressure, ci/ca (unitless)
     real :: xi                  ! relative cost parameter, Eq. 9 in Stocker et al., 2019 GMD
     real :: iwue                ! intrinsic water use efficiency = A / gs = ca - ci = ca ( 1 - chi ) , unitless
     real :: lue                 ! light use efficiency (mol CO2 / mol photon)
     ! real :: assim               ! leaf-level assimilation rate (mol CO2 m-2 s-1)
-    real :: gs_setpoint         ! stomatal conductance to CO2 (mol C Pa-1 m-2 s-1)
+    real :: gs_setpoint         ! stomatal conductance to CO2 (mol CO2 Pa-1 (mol photons)-1)
     ! real :: gs_unitfapar        ! stomatal conductance to CO2 per unit fapar (mol C Pa-1 m-2 s-1)
-    ! real :: gs_unitiabs         ! stomatal conductance to CO2 per unit absorbed light (mol C Pa-1 m-2 s-1)
-    ! real :: gpp                 ! gross primary productivity (g CO2 m-2 d-1)
+    ! real :: gs_unitiabs         ! stomatal conductance to CO2 per unit absorbed light (mol CO2 Pa-1 (mol photons)-1)
+    ! real :: gpp                 ! gross primary productivity (g CO2 m-2 s-1)
     ! real :: vcmax               ! canopy-level maximum carboxylation capacity per unit ground area (mol CO2 m-2 s-1)
     real :: jmax25              ! canopy-level maximum rate of electron transport, normalized to 25 deg C (mol m-2 s-1)
     real :: vcmax25             ! canopy-level Vcmax25 (Vcmax normalized to 25 deg C) (mol CO2 m-2 s-1)
@@ -38,9 +38,9 @@ module md_photosynth
     ! real :: vcmax_unitiabs      ! Vcmax per unit absorbed light (mol CO2 m-2 s-1 mol-1)
     ! real :: ftemp_inst_vcmax    ! Instantaneous temperature response factor of Vcmax (unitless)
     ! real :: ftemp_inst_rd       ! Instantaneous temperature response factor of Rd (unitless)
-    ! real :: rd                  ! Dark respiration (mol CO2 m-2 s-1)
-    ! real :: rd_unitfapar        ! Dark respiration per unit fAPAR (mol CO2 m-2 s-1)
-    ! real :: rd_unitiabs         ! Dark respiration per unit absorbed light (mol CO2 m-2 s-1)
+    ! real :: rd                  ! Dark respiration (g C m-2 s-1)
+    ! real :: rd_unitfapar        ! Dark respiration per unit fAPAR (g C m-2 s-1)
+    ! real :: rd_unitiabs         ! Dark respiration per unit absorbed light (g C (mol photons)-1)
     real :: actnv               ! Canopy-level total metabolic leaf N per unit ground area (g N m-2)
     real :: actnv_unitfapar     ! Metabolic leaf N per unit fAPAR (g N m-2)
     real :: actnv_unitiabs      ! Metabolic leaf N per unit absorbed light (g N m-2 mol-1)
@@ -70,7 +70,7 @@ module md_photosynth
 
 contains
 
-  function pmodel( kphio, beta, kc_jmax, ppfd, co2, tc, vpd, patm, c4, method_optci, method_jmaxlim ) result( out_pmodel )
+  function pmodel( kphio, beta, kc_jmax, ppfd, co2, tc, vpd, patm, tc_home, c4, method_optci, method_jmaxlim ) result( out_pmodel )
     !//////////////////////////////////////////////////////////////////
     ! Implements the P-model, providing predictions for ci, Vcmax, and 
     ! light use efficiency, etc. 
@@ -78,15 +78,16 @@ contains
     ! function calc_dgpp().
     !------------------------------------------------------------------
     ! arguments
-    real, intent(in) :: kphio        ! apparent quantum yield efficiency       
-    real, intent(in) :: beta         ! parameter for the unit cost ratio (corresponding to beta in Prentice et al., 2014)    
-    real, intent(in) :: kc_jmax      ! parameter Jmax cost ratio (corresponding to c in Prentice et al., 2014)    
+    real, intent(in) :: kphio        ! apparent quantum yield efficiency (mol mol-1)
+    real, intent(in) :: beta         ! parameter for the unit cost ratio (-) (corresponding to beta in Prentice et al., 2014)    
+    real, intent(in) :: kc_jmax      ! parameter Jmax cost ratio (-) (corresponding to c in Prentice et al., 2014)    
     ! real, intent(in) :: fapar        ! fraction of absorbed photosynthetically active radiation (unitless) 
     real, intent(in) :: ppfd         ! photosynthetic photon flux density (mol m-2 s-1), relevant for acclimated response
     real, intent(in) :: co2          ! atmospheric CO2 concentration (ppm), relevant for acclimated response
     real, intent(in) :: tc           ! air temperature (deg C), relevant for acclimated response
     real, intent(in) :: vpd          ! vapor pressure (Pa), relevant for acclimated response
     real, intent(in) :: patm         ! atmospheric pressure (Pa), relevant for acclimated response
+    real, intent(in) :: tc_home      ! long-term mean max temp of the warmest month (deg C)
     logical, intent(in) :: c4        ! whether or not C4 photosynthesis pathway is followed. If .false., it's C3.
     character(len=*), intent(in) :: method_optci    ! Method used for deriving optimal ci:ca
     character(len=*), intent(in) :: method_jmaxlim  ! Method used for accounting for Jmax limitation
@@ -99,9 +100,7 @@ contains
     real :: kmm                 ! Michaelis-Menten coefficient (Pa)
     real :: gammastar           ! photorespiratory compensation point - Gamma-star (Pa)
     real :: ca                  ! ambient CO2 partial pressure, (Pa)
-    real :: gs_setpoint         ! stomatal conductance to CO2 (mol CO2 Pa-1 m-2 s-1)
-    ! real :: gs_unitfapar        ! stomatal conductance to CO2 (mol CO2 Pa-1 m-2 s-1)
-    ! real :: gs_unitiabs         ! stomatal conductance to CO2 (mol CO2 Pa-1 m-2 s-1)
+    real :: gs_setpoint         ! stomatal conductance to CO2 (mol CO2 Pa-1 (mol photons)-1)
     real :: ci                  ! leaf-internal partial pressure, (Pa)
     real :: chi                 ! = ci/ca, leaf-internal to ambient CO2 partial pressure, ci/ca (unitless)
     real :: ns                  ! viscosity of H2O at ambient temperatures (Pa s)
@@ -110,29 +109,18 @@ contains
     real :: mprime              ! factor in light use model with Jmax limitation
     real :: iwue                ! intrinsic water use efficiency = A / gs = ca - ci = ca ( 1 - chi ) , unitless
     real :: lue                 ! light use efficiency (mol CO2 / mol photon)
-    ! real :: gpp                 ! gross primary productivity (g CO2 m-2 d-1)
     real :: jmax                ! canopy-level maximum rate of electron transport (XXX)
     real :: jmax25              ! canopy-level maximum rate of electron transport (XXX)
     real :: vcmax               ! canopy-level maximum carboxylation capacity per unit ground area (mol CO2 m-2 s-1)
     real :: vcmax25             ! canopy-level Vcmax25 (Vcmax normalized to 25 deg C) (mol CO2 m-2 s-1)
     real :: vcmax_star          ! 
-    ! real :: vcmax_unitfapar     ! Vcmax per unit fAPAR (mol CO2 m-2 s-1)
-    ! real :: vcmax25_unitfapar   ! Vcmax25 per unit fAPAR (mol CO2 m-2 s-1)
-    ! real :: vcmax_unitiabs      ! Vcmax per unit absorbed light (mol CO2 m-2 s-1 mol-1)
-    ! real :: vcmax25_unitiabs    ! Vcmax25 per unit absorbed light (mol CO2 m-2 s-1 mol-1)
     real :: ftemp_inst_vcmax    ! Instantaneous temperature response factor of Vcmax (unitless)
     real :: ftemp_inst_jmax     ! Instantaneous temperature response factor of Jmax (unitless)
-    ! real :: rd                  ! Dark respiration (mol CO2 m-2 s-1)
-    ! real :: rd_unitfapar        ! Dark respiration per unit fAPAR (mol CO2 m-2 s-1)
-    ! real :: rd_unitiabs         ! Dark respiration per unit absorbed light (mol CO2 m-2 s-1)
     real :: actnv               ! Canopy-level total metabolic leaf N per unit ground area (g N m-2)
-    ! real :: actnv_unitfapar     ! Metabolic leaf N per unit fAPAR (g N m-2)
-    ! real :: actnv_unitiabs      ! Metabolic leaf N per unit absorbed light (g N m-2 mol-1)
-    ! real :: transp              ! Canopy-level total transpiration rate (g H2O (mol photons)-1)
     real :: fact_jmaxlim        ! Jmax limitation factor (unitless)
 
     ! local variables for Jmax limitation following Nick Smith's method
-    real :: omega, omega_star, tcref, jmax_over_vcmax, jmax_prime
+    real :: omega, omega_star, tc_ref, jmax_over_vcmax, jmax_prime
 
     real, parameter :: theta = 0.85          ! used only for smith19 setup
     real, parameter :: c_cost = 0.05336251   ! used only for smith19 setup
@@ -163,7 +151,7 @@ contains
     ! XXX PMODEL_TEST: ok
     ! print*,'kmm:       ', kmm
 
-    ! viscosity correction factor = viscosity( temp, press )/viscosity( 25 degC, 1013.25 Pa) 
+    ! viscosity correction factor = viscosity( temp, press )/viscosity( 25 deg C, 1013.25 Pa) 
     ns      = calc_viscosity_h2o( tc, patm )  ! Pa s 
     ns25    = calc_viscosity_h2o( 25.0, kPo )  ! Pa s 
     ns_star = ns / ns25                       ! (unitless)
@@ -239,7 +227,8 @@ contains
       lue = kphio * mprime * c_molmass  ! in g CO2 m-2 s-1 / (mol light m-2 s-1)
       
       ! Vcmax after accounting for Jmax limitation
-      vcmax = kphio * ppfd * out_optchi%mjoc * mprime / out_optchi%mj
+      vcmax = kphio * ppfd * out_optchi%mjoc * mprime / out_optchi%mj ! mol m-2 s-1
+      !       (-)   * (mol m-2 s-1) *    (-) * (-)    / (-)
 
       ! xxx test
       ! print*,'out_optchi%mjoc : ', out_optchi%mjoc 
@@ -261,15 +250,15 @@ contains
       omega = calc_omega( theta = theta, c_cost = c_cost, m = out_optchi%mj )             ! Eq. S4
       omega_star = 1.0 + omega - sqrt( (1.0 + omega)**2 - (4.0 * theta * omega) )       ! Eq. 18
       
-      ! calculate Vcmax-star, which corresponds to Vcmax at a reference temperature 'tcref'
+      ! calculate Vcmax-star, which corresponds to Vcmax at a reference temperature 'tc_ref'
       vcmax_star  = kphio * ppfd * out_optchi%mjoc * omega_star / (8.0 * theta)               ! Eq. 19
       
-      ! tcref is the optimum temperature in K, assumed to be the temperature at which Vcmax* is operating. 
-      ! tcref is estimated based on its relationship to growth temperature following Kattge & Knorr 2007
-      tcref = 0.44 * tc + 24.92
+      ! tc_ref is the optimum temperature in K, assumed to be the temperature at which Vcmax* is operating. 
+      ! tc_ref is estimated based on its relationship to growth temperature following Kattge & Knorr 2007
+      tc_ref = 0.44 * tc + 24.92
 
       ! calculated acclimated Vcmax at prevailing growth temperatures
-      ftemp_inst_vcmax = calc_ftemp_inst_vcmax( tc, tc, tcref = tcref )
+      ftemp_inst_vcmax = calc_ftemp_inst_vcmax( tc, tc, tc_ref = tc_ref )
       vcmax = vcmax_star * ftemp_inst_vcmax   ! Eq. 20
       
       ! calculate Jmax
@@ -277,8 +266,7 @@ contains
       jmax_prime = jmax_over_vcmax * vcmax 
 
       ! light use efficiency
-      lue = c_molmass * kphio * out_optchi%mj * omega_star / (8.0 * theta) ! * calc_ftemp_inst_vcmax( tc, tc, tcref = tcref )     ! treat theta as a calibratable parameter
-
+      lue = c_molmass * kphio * out_optchi%mj * omega_star / (8.0 * theta) ! treat theta as a calibratable parameter
 
     else if (method_jmaxlim=="none") then
 
@@ -306,13 +294,9 @@ contains
     ! Corrolary preditions (This is prelimirary!)
     !-----------------------------------------------------------------------
     ! Vcmax25 (vcmax normalized to 25 deg C)
-    ftemp_inst_vcmax  = calc_ftemp_inst_vcmax( tc, tc, tcref = 25.0 )
+    ftemp_inst_vcmax  = calc_ftemp_inst_vcmax( tc, tc, tc_ref = 25.0 )
     vcmax25  = vcmax / ftemp_inst_vcmax
 
-    ! ! Dark respiration at growth temperature
-    ! ftemp_inst_rd = calc_ftemp_inst_rd( tc )
-    ! rd  = params_gpp%rd_to_vcmax * (ftemp_inst_rd / ftemp_inst_vcmax) * vcmax 
-
     ! active metabolic leaf N (canopy-level), mol N/m2-ground (same equations as for nitrogen content per unit leaf area, gN/m2-leaf)
     actnv  = vcmax25 * n_v
 
@@ -327,10 +311,11 @@ contains
       if (fact_jmaxlim >= 1 .or. fact_jmaxlim <= 0) then
         jmax = dummy
       else
-        jmax = 4.0 * kphio * ppfd / sqrt( (1.0/fact_jmaxlim)**2 - 1.0 )
+        jmax = 4.0 * kphio * ppfd / sqrt( (1.0/fact_jmaxlim)**2 - 1.0 ) ! mol m-2 s-1
+        !      (-) * (-)   * (mol m-2 s-1) / (-)
       end if
       ! for normalization using temperature response from Duursma et al., 2015, implemented in plantecophys R package
-      ftemp_inst_jmax  = calc_ftemp_inst_jmax( tc, tc, tcref = 25.0 )
+      ftemp_inst_jmax  = calc_ftemp_inst_jmax(tc, tc, tc_home, tc_ref = 25.0 )
       jmax25  = jmax  / ftemp_inst_jmax
     end if
 
@@ -343,110 +328,6 @@ contains
     end if
 
 
-    ! if (ppfd /= dummy) then
-    !   !-----------------------------------------------------------------------
-    !   ! Calculate quantities scaling with light assuming fAPAR = 1
-    !   ! representing leaf-level at the top of the canopy.
-    !   !-----------------------------------------------------------------------
-    !   ! ! leaf-level assimilation rate
-    !   ! assim = lue * ppfd
-
-    !   ! ! Transpiration (E)
-    !   ! transp = 1.6 * gs * vpd
-
-    !   ! Vcmax normalised per unit fAPAR (assuming fAPAR=1)
-    !   vcmax_unitfapar = ppfd * vcmax_unitiabs
-
-    !   ! Vcmax25 (vcmax normalized to 25 deg C)
-    !   vcmax25_unitfapar = ppfd * vcmax25_unitiabs
-
-    !   ! ! Dark respiration per unit fAPAR (assuming fAPAR=1)
-    !   ! rd_unitfapar = ppfd * rd_unitiabs
-
-    !   ! active metabolic leaf N (canopy-level), mol N/m2-ground (same equations as for nitrogen content per unit leaf area, gN/m2-leaf)
-    !   actnv_unitfapar = ppfd * actnv_unitiabs
-
-    !   ! stomatal conductance to CO2, expressed per unit absorbed fAPAR
-    !   gs_unitfapar = ppfd * gs_unitiabs
-
-
-    !   if (fapar /= dummy) then
-    !     !-----------------------------------------------------------------------
-    !     ! Calculate quantities scaling with absorbed light
-    !     !-----------------------------------------------------------------------
-    !     ! absorbed photosynthetically active radiation (mol/m2)
-    !     iabs = fapar * ppfd 
-
-    !     ! XXX PMODEL_TEST: ok
-    !     ! print*,'iabs ', iabs
-
-    !     ! Canopy-level quantities 
-    !     ! Defined per unit ground level -> scaling with aborbed light (iabs)
-    !     !-----------------------------------------------------------------------
-    !     ! Gross primary productivity
-    !     gpp = iabs * lue ! in g C m-2 s-1
-
-    !     ! ! XXX PMODEL_TEST: ok
-    !     ! print*,'gpp ', gpp
-
-    !     ! Vcmax per unit ground area is the product of the intrinsic quantum 
-    !     ! efficiency, the absorbed PAR, and 'n'
-    !     vcmax = iabs * vcmax_unitiabs  ! = iabs * kphio * n 
-
-    !     ! ! XXX PMODEL_TEST: ok
-    !     ! print*,'vcmax ', vcmax
-
-    !     ! (vcmax normalized to 25 deg C)
-    !     vcmax25 = iabs * vcmax25_unitiabs  ! = factor25_vcmax * vcmax
-
-    !     ! ! XXX PMODEL_TEST: ok
-    !     !print*,'vcmax25 ', vcmax25
-    !     !print*,'vcmax25 ', vcmax25_unitiabs
-    !     ! Dark respiration
-    !     ! rd = iabs * rd_unitiabs ! = rd_to_vcmax * vcmax
-
-    !     ! ! XXX PMODEL_TEST: ok
-    !     ! print*,'rd ', rd
-
-    !     ! active metabolic leaf N (canopy-level), mol N/m2-ground (same equations as for nitrogen content per unit leaf area, gN/m2-leaf)
-    !     actnv = iabs * actnv_unitiabs ! = vcmax25 * n_v
-
-    !     ! stomatal conductance to CO2
-    !     gs = iabs * gs_unitiabs
-
-    !     ! xxx text here we have ignored gs_test, otherwise it will cause FPE
-    !     !gs_test = (gpp / c_molmass) / (ca - ci)
-    !     ! print*,'pmodel(): gs, gs_test ', gs, gs_test
-
-
-
-    !   else
-
-    !     ! gpp     = dummy
-    !     ! vcmax   = dummy
-    !     vcmax25 = dummy
-    !     ! rd      = dummy
-    !     ! actnv   = dummy
-    !     jmax    = dummy
-
-    !   end if
-
-    ! else
-
-    !   ! vcmax_unitfapar   = dummy
-    !   vcmax25_unitfapar = dummy
-    !   ! rd_unitfapar      = dummy
-    !   ! actnv_unitfapar   = dummy
-      
-    !   ! gpp               = dummy
-    !   vcmax             = dummy
-    !   vcmax25           = dummy
-    !   ! rd                = dummy
-    !   ! actnv             = dummy
-    !   jmax              = dummy
-
-    ! end if
-
     ! construct list for output
     out_pmodel%gammastar        = gammastar
     out_pmodel%kmm              = kmm
@@ -456,23 +337,9 @@ contains
     out_pmodel%xi               = out_optchi%xi
     out_pmodel%iwue             = iwue
     out_pmodel%lue              = lue
-    ! out_pmodel%gpp              = gpp
-    ! out_pmodel%vcmax            = vcmax
-    ! out_pmodel%jmax             = jmax
     out_pmodel%vcmax25          = vcmax25
     out_pmodel%jmax25           = jmax25
-    ! out_pmodel%vcmax_unitfapar  = vcmax_unitfapar
-    ! out_pmodel%vcmax_unitiabs   = vcmax_unitiabs
-    ! out_pmodel%ftemp_inst_vcmax = ftemp_inst_vcmax
-    ! out_pmodel%ftemp_inst_jmax    = ftemp_inst_jmax
-    ! out_pmodel%rd               = rd
-    ! out_pmodel%rd_unitfapar     = rd_unitfapar
-    ! out_pmodel%rd_unitiabs      = rd_unitiabs
     out_pmodel%actnv            = actnv
-    ! out_pmodel%actnv_unitfapar  = actnv_unitfapar
-    ! out_pmodel%actnv_unitiabs   = actnv_unitiabs
-    ! out_pmodel%gs_unitiabs      = gs_unitiabs
-    ! out_pmodel%gs_unitfapar     = gs_unitfapar
     out_pmodel%gs_setpoint      = gs_setpoint
 
   end function pmodel
@@ -665,6 +532,28 @@ contains
   end function calc_omega
 
 
+  pure function calc_bigdelta( chi, ca, gammastar ) result( bigdelta )
+    !-------------------------------------------------------------
+    ! Calculates isotopic discrimination (Delta) against 13C
+    !-------------------------------------------------------------
+    ! arguments
+    real, intent(in) :: chi        ! = ci/ca, leaf-internal to ambient CO2 partial pressure, ci/ca (unitless)
+    real, intent(in) :: ca         ! leaf-external (ambient) CO2 partial pressure, (Pa)
+    real, intent(in) :: gammastar  ! temperature-dependent photorespiratory compensation point (Pa)
+
+    ! local variables
+    real, parameter :: a_par = 4.4   ! isotope fractionation from CO2 diffusion in air (4.4 permil; Craig, 1953)
+    real, parameter :: b_par = 27.0  ! isotope fractionation from effective Rubisco carboxylation (26–30 permil)
+    real, parameter :: f_par = 8.0   ! isotope fractionation from photorespiration (8–16 permil; Ubierna & Farquhar, 2014)
+
+    ! function return variable
+    real :: bigdelta
+
+    bigdelta = chi * (b_par - a_par) + a_par - f_par * gammastar / ca !(e.g. eq 4; Brüggemann, 10.5194/bg-8-3457-2011)
+
+  end function calc_bigdelta
+
+
   ! function findroot_quadratic( aquad, bquad, cquad, return_smallroot ) result( root )
   !   !-----------------------------------------------------------------------
   !   ! Returns the solution for a quadratic function:
@@ -838,9 +727,9 @@ contains
     ! arguments
     real, intent(in) :: dtemp    ! (leaf) temperature in degrees celsius
     logical, intent(in) :: c4
-    real, intent(in) :: kphio
-    real, intent(in) :: kphio_par_a
-    real, intent(in) :: kphio_par_b
+    real, intent(in) :: kphio        ! (mol mol-1)
+    real, intent(in) :: kphio_par_a  ! ((deg C)-2)
+    real, intent(in) :: kphio_par_b  ! (deg C)
 
     ! function return variable
     real :: kphio_temp
@@ -894,107 +783,97 @@ contains
   end function calc_ftemp_inst_rd
 
 
-  function calc_ftemp_inst_vcmax( tcleaf, tcgrowth, tcref ) result( fv )
+  function calc_ftemp_inst_vcmax( tc_leaf, tc_growth, tc_ref ) result( fv )
     !-----------------------------------------------------------------------
-    ! arguments
-    ! tcleaf: temperature (degrees C)
-    ! tref: is 'to' in Nick's set it to 25 C (=298.15 K in other cals)
+    ! Calculates the instantaneous temperature response factor for Vcmax.
     !
-    ! function return variable
-    ! fv: temperature response factor, relative to 25 deg C.
+    ! Arguments:
+    !   tc_leaf:    Instantaneous leaf temperature (°C)
+    !   tc_growth:  Growth temperature, 30-day mean damped temperature (°C)
+    !   tc_home:    Long-term mean maximum temperature of the warmest month (°C)
+    !   tc_ref:     Reference temperature (°C), is 'to' in Nick's set it to 25 °C (=298.15 K in other cals)
     !
-    ! Output:   Factor fv to correct for instantaneous temperature response
-    !           of Vcmax for:
-    !
-    !               Vcmax(temp) = fv * Vcmax(25 deg C) 
-    !
-    ! Ref:      Wang Han et al. (in prep.)
+    ! Returns:
+    !   fv:        Instantaneous temperature response factor (unitless)
+    
+    ! Reference:   
+    !   Kumarathunge et al. (2019), Eq. 7
     !-----------------------------------------------------------------------
-    ! arguments
-    real, intent(in) :: tcleaf
-    real, intent(in) :: tcgrowth
-    real, intent(in), optional :: tcref
 
-    ! function return variable
+    ! Function arguments
+    real, intent(in) :: tc_leaf
+    real, intent(in) :: tc_growth
+    real, intent(in) :: tc_ref
+
+    ! Local variables
+    real :: tk_ref, tk_leaf, dent, fva, fvb
+    real :: Ha, Hd
+
+    ! Output variable
     real :: fv
 
-    ! loal parameters
-    real, parameter :: Ha    = 71513  ! activation energy (J/mol)
-    real, parameter :: Hd    = 200000 ! deactivation energy (J/mol)
-    real, parameter :: a_ent = 668.39 ! offset of entropy vs. temperature relationship from Kattge & Knorr (2007) (J/mol/K)
-    real, parameter :: b_ent = 1.07   ! slope of entropy vs. temperature relationship from Kattge & Knorr (2007) (J/mol/K^2)
+    ! Constants (defined here or globally)
+    Ha = (42.6 + 1.14 * tc_growth) * 1.0e3  ! activation energy (J/mol)
+    Hd = 200000.0                           ! deactivation energy (J/mol)
+    ! kR                                    ! kR is universal gas constant (J/mol/K)
     
-    ! local variables
-    real :: tkref, tkleaf, dent, fva, fvb, mytcref
-
-    if (present(tcref)) then
-      mytcref = tcref
-    else
-      mytcref = 298.15
-    end if
-
-    tkref = mytcref + 273.15  ! to Kelvin
-
-    ! conversion of temperature to Kelvin, tcleaf is the instantaneous leaf temperature in degrees C. 
-    tkleaf = tcleaf + 273.15
-
-    ! calculate entropy following Kattge & Knorr (2007), negative slope and y-axis intersect is when expressed as a function of temperature in degrees Celsius, not Kelvin !!!
-    dent = a_ent - b_ent * tcgrowth   ! 'tcgrowth' corresponds to 'tmean' in Nicks, 'tc25' is 'to' in Nick's
-    fva = calc_ftemp_arrhenius( tkleaf, Ha, tkref )
-    fvb = (1.0 + exp( (tkref * dent - Hd)/(kR * tkref) ) ) / (1.0 + exp( (tkleaf * dent - Hd)/(kR * tkleaf) ) )
+    tk_ref  = tc_ref  + 273.15  ! to Kelvin
+    tk_leaf = tc_leaf + 273.15  ! to Kelvin
+    
+    ! Calculate Ha ("Ea") and dent ("Delta S") based on Kumarathunge et al. (2019) for Vcmax
+    dent = 645.13 - 0.38 * tc_growth      ! J/mol/K
+    fva = calc_ftemp_arrhenius( tk_leaf, Ha, tk_ref ) 
+    fvb = (1.0 + exp( (tk_ref * dent - Hd)/(kR * tk_ref) )) / (1.0 + exp( (tk_leaf * dent - Hd)/(kR * tk_leaf) ))
     fv  = fva * fvb
 
   end function calc_ftemp_inst_vcmax
 
 
-  function calc_ftemp_inst_jmax( tcleaf, tcgrowth, tcref ) result( fv )
+  function calc_ftemp_inst_jmax( tc_leaf, tc_growth, tc_home, tc_ref ) result( fv )
     !-----------------------------------------------------------------------
-    ! Calculates the instantaneous temperature response of Jmax
+    ! Calculates the instantaneous temperature response factor for Jmax.
     ! 
-    ! Given Jmax at a reference temperature (argument tcref)
-    ! this function calculates its temperature-scaling factor following modified Arrhenius
-    ! kinetics based on Kattge & Knorr (2007).
+    ! Arguments:
+    !   tc_leaf:    Instantaneous leaf temperature (°C)
+    !   tc_growth:  Growth temperature, 30-day mean damped temperature (°C)
+    !   tc_home:    Long-term mean maximum temperature of the warmest month (°C)
+    !   tc_ref:     Reference temperature (°C), is 'to' in Nick's set it to 25 °C (=298.15 K in other cals)
     !
-    ! Reference:
-    ! Kattge, J. and Knorr, W.: Temperature acclimation in a biochemical model of 
-    ! photosynthesis: a reanalysis of data from 36 species, Plant, Cell and Environment, 
-    ! 30,1176â1190, 2007.
+    ! Returns:
+    !   fv:        Instantaneous temperature response factor (unitless)
+    
+    ! Reference:   
+    !   Kumarathunge et al. (2019), Eq. 7
     !-----------------------------------------------------------------------
-    ! arguments
-    real, intent(in) :: tcleaf
-    real, intent(in) :: tcgrowth
-    real, intent(in), optional :: tcref
 
-    ! function return variable
+    ! Function arguments
+    real, intent(in) :: tc_leaf
+    real, intent(in) :: tc_growth
+    real, intent(in) :: tc_home
+    real, intent(in) :: tc_ref
+
+    ! Local variables
+    real :: tk_ref, tk_leaf, dent, fva, fvb
+    real :: Hd, Ha
+
+    ! Output variable
     real :: fv
 
-    ! loal parameters
-    real, parameter :: Ha    = 49884  ! activation energy (J/mol)
-    real, parameter :: Hd    = 200000 ! deactivation energy (J/mol)
-    real, parameter :: a_ent = 659.70 ! offset of entropy vs. temperature relationship from Kattge & Knorr (2007) (J/mol/K)
-    real, parameter :: b_ent = 0.75   ! slope of entropy vs. temperature relationship from Kattge & Knorr (2007) (J/mol/K^2)
+    ! Constants (defined here or globally)
+    Ha = 40710.0   ! J/mol (constant activation energy for Jmax)
+    Hd = 200000.0  ! deactivation energy (J/mol)
+    ! kR           ! kR is universal gas constant (J/mol/K)
     
-    ! local variables
-    real :: tkref, tkleaf, dent, fva, fvb, mytcref
+    tk_ref  = tc_ref  + 273.15  ! to Kelvin
+    tk_leaf = tc_leaf + 273.15  ! to Kelvin
 
-    if (present(tcref)) then
-      mytcref = tcref
-    else
-      mytcref = 298.15
-    end if
-
-    tkref = mytcref + 273.15  ! to Kelvin
-
-    ! conversion of temperature to Kelvin, tcleaf is the instantaneous leaf temperature in degrees C. 
-    tkleaf = tcleaf + 273.15
-
-    ! calculate entropy following Kattge & Knorr (2007), negative slope and y-axis intersect is when expressed as a function of temperature in degrees Celsius, not Kelvin !!!
-    dent = a_ent - b_ent * tcgrowth   ! 'tcgrowth' corresponds to 'tmean' in Nicks, 'tc25' is 'to' in Nick's
-    fva = calc_ftemp_arrhenius( tkleaf, Ha, tkref )
-    fvb = (1.0 + exp( (tkref * dent - Hd)/(kR * tkref) ) ) / (1.0 + exp( (tkleaf * dent - Hd)/(kR * tkleaf) ) )
+    ! Calculate Ha ("Ea") and dent ("Delta S") based on Kumarathunge et al. (2019) for Jmax
+    dent = 658.77 - 0.84 * tc_home - 0.52 * (tc_growth - tc_home)  ! J/mol/K
+    fva = calc_ftemp_arrhenius( tk_leaf, Ha, tk_ref ) 
+    fvb = (1.0 + exp( (tk_ref * dent - Hd)/(kR * tk_ref) )) / (1.0 + exp( (tk_leaf * dent - Hd)/(kR * tk_leaf) ))
     fv  = fva * fvb
 
-  end function calc_ftemp_inst_jmax  
+  end function calc_ftemp_inst_jmax
 
 
   function calc_ftemp_arrhenius( tk, dha, tkref ) result( ftemp )
@@ -1017,6 +896,9 @@ contains
     ! function return variable
     real :: ftemp
 
+    ! Constants (defined here or globally)
+    ! kR                ! kR is universal gas constant (J/mol/K)
+
     if (present(tkref)) then
       mytkref = tkref
     else
@@ -1027,37 +909,6 @@ contains
 
   end function calc_ftemp_arrhenius
 
-  ! XXX REMOVED BECAUSE IT'S NOW IN SOFUNUTILS
-  ! function calc_patm( elv ) result( patm )
-  !   !-----------------------------------------------------------------------
-  !   ! Features: Returns the atmospheric pressure as a function of elevation
-  !   !           and standard atmosphere (1013.25 hPa)
-  !   ! Depends:  - connect_sql
-  !   !           - flux_to_grid
-  !   !           - get_data_point
-  !   !           - get_msvidx
-  !   ! Ref:      Allen et al. (1998)
-  !   !-----------------------------------------------------------------------
-  !   ! argument
-  !   real, intent(in) :: elv           ! elevation above sea level, m
-
-  !   ! local variables
-  !   real, parameter :: kPo = 101325   ! standard atmosphere, Pa (Allen, 1973)
-  !   real, parameter :: kTo = 298.15   ! base temperature, K (Prentice, unpublished)
-  !   real, parameter :: kL  = 0.0065   ! temperature lapse rate, K/m (Allen, 1973)
-  !   real, parameter :: kG  = 9.80665  ! gravitational acceleration, m/s**2 (Allen, 1973)
-  !   real, parameter :: kR  = 8.3145   ! universal gas constant, J/mol/K (Allen, 1973)
-  !   real, parameter :: kMa = 0.028963 ! molecular weight of dry air, kg/mol (Tsilingiris, 2008)
-
-  !   ! function return variable
-  !   real :: patm    ! atmospheric pressure at elevation 'elv', Pa 
-
-  !   ! Convert elevation to pressure, Pa:
-  !   patm = kPo*(1.0 - kL*elv/kTo)**(kG*kMa/(kR*kL))
-    
-  ! end function calc_patm
-
-
   function calc_density_h2o( tc, patm ) result( density_h2o )
     !-----------------------------------------------------------------------
     ! Features: Calculates density of water at a given temperature and 
