@@ -5,14 +5,13 @@ module md_plant_pmodel
   !----------------------------------------------------------------
   use md_params_core, only: ndayyear, npft, nlu, lunat
   use md_interface_pmodel, only: myinterface
+  use md_orgpool
 
   implicit none
 
   private
   public plant_type, plant_fluxes_type, getpar_modl_plant, &
-    initglobal_plant, &
-    params_pft_plant
-    ! get_leaftraits, 
+    init_plant, params_pft_plant
 
   !----------------------------------------------------------------
   ! Public, module-specific state variables
@@ -50,47 +49,43 @@ module md_plant_pmodel
     real :: acrown              ! crown area
 
     ! leaf traits
-    ! real :: vcmax25             ! canopy-level Vcmax25 (Vcmax normalized to 25 deg C) (mol CO2 m-2 s-1)
-    ! real :: jmax25              ! total leaf N per unit leaf area (gN m-2)
-    
     real :: narea               ! total leaf N per unit leaf area (gN m-2)
     real :: narea_metabolic     ! metabolic leaf N per unit leaf area (gN m-2)
     real :: narea_structural    ! structural leaf N per unit leaf area (gN m-2)
     real :: lma                 ! leaf mass per area (gC m-2)
     real :: sla                 ! specific leaf area (m2 gC-1)
     real :: nmass               ! leaf N per unit leaf mass, g N / g-dry mass
-    real :: r_cton_leaf         ! leaf C:N ratio [gC/gN] 
-    real :: r_ntoc_leaf         ! leaf N:C ratio [gN/gC]
+    real :: r_cton_leaf         ! leaf C:N ratio (gC/gN)
+    real :: r_ntoc_leaf         ! leaf N:C ratio (gN/gC)
+
+    ! pools
+    type(orgpool) :: pleaf      ! leaf biomass
 
   end type plant_type
 
-
   !----------------------------------------------------------------
   ! Fluxes and other variables with no memory
   !----------------------------------------------------------------
   type plant_fluxes_type
 
     ! daily updated variables
-    real :: dgpp              ! daily gross primary production [gC/m2/d]           
-    real :: drd               ! daily dark respiration [gC/m2/d]
+    real :: dgpp              ! daily gross primary production (gC m-2 d-1)
+    real :: drd               ! daily dark respiration (gC m-2 d-1)
     real :: assim             ! daily assimilation (mol CO2 m-2 s-1)
-    real :: dtransp           ! daily transpiration [mm]
-    real :: dlatenth          ! daily latent heat flux [J m-2 d-1]
+    real :: dtransp           ! daily transpiration (mm)
+    real :: dlatenth          ! daily latent heat flux (J m-2 d-1)
     
     real :: vcmax25           ! acclimated Vcmax, normalised to 25 deg C (mol CO2 m-2 s-1)
     real :: jmax25            ! acclimated Jmax, normalised to 25 deg C (mol CO2 m-2 s-1)
     real :: vcmax             ! daily varying Vcmax (mol CO2 m-2 s-1)
     real :: jmax              ! daily varying Jmax (mol CO2 m-2 s-1)
-    real :: gs_accl           ! acclimated stomatal conductance (xxx)
+    real :: gs_accl           ! acclimated stomatal conductance (mol CO2 Pa-1 (mol photons)-1)
     real :: chi               ! ci:ca ratio (unitless)
     real :: iwue              ! intrinsic water use efficiency (A/gs = ca*(1-chi))
+    real :: bigdelta          ! 13C discrimination by photosynthesis, expressed as the difference to the atmospheric signature (permil)
+    real :: d13c_gpp          ! delta-13C isotopic signature, small delta (permil) ! NOTE: instead of d13c_gpp as real, we could define dgpp as orgpool()
 
-    ! ! annual variables
-    ! real :: agpp             ! annual total gross primary production [gC/m2/yr]           
-    ! real :: avcmax25_mean    ! annual Vcmax, normalised to 25 deg C, GPP-weighted mean
-    ! real :: avcmax25_max     ! annual Vcmax, normalised to 25 deg C, annual maximum
-
-  end type plant_fluxes_type
+  end type plant_fluxes_type ! if type is changed, change initialization, too: initdaily_tile_fluxes()
 
 
 contains
@@ -233,7 +228,7 @@ contains
     character(len=*), intent(in) :: pftname
 
     ! local variables
-    integer :: lu_category_prov = 0   ! land use category associated with PFT (provisional)
+    integer, parameter :: lu_category_prov = 1   ! land use category associated with PFT (provisional)
 
     ! function return variable
     type( params_pft_plant_type ) :: out_getpftparams
@@ -293,7 +288,7 @@ contains
   end function getpftparams
 
 
-  subroutine initglobal_plant( plant )
+  subroutine init_plant( plant )
     !////////////////////////////////////////////////////////////////
     !  Initialisation of all _pools on all gridcells at the beginning
     !  of the simulation.
@@ -304,42 +299,27 @@ contains
     ! local variables
     integer :: pft
 
-    !-----------------------------------------------------------------------------
-    ! derive which PFTs are present from fpc_grid (which is prescribed)
-    !-----------------------------------------------------------------------------
-    do pft=1,npft
-      call initpft( plant(pft) )
-      plant(pft)%pftno = pft
-    end do
-
-  end subroutine initglobal_plant
-
-
-  subroutine initpft( plant )
-    !////////////////////////////////////////////////////////////////
-    !  Initialisation of specified PFT on specified gridcell
-    !----------------------------------------------------------------
-    ! argument
-    type( plant_type ), intent(inout) :: plant
-
-    plant%fpc_grid  = 0.0
-    plant%lai_ind   = 0.0
-    plant%fapar_ind = 0.0
-    plant%acrown    = 0.0
+    plant(:)%fpc_grid  = 0.0
+    plant(:)%lai_ind   = 0.0
+    plant(:)%fapar_ind = 0.0
+    plant(:)%acrown    = 0.0
 
     ! canpopy state variables
-    ! plant%vcmax25          = 0.0
-    ! plant%jmax25           = 0.0
-    plant%narea            = 0.0
-    plant%narea_metabolic  = 0.0
-    plant%narea_structural = 0.0
-    plant%lma              = 0.0
-    plant%sla              = 0.0
-    plant%nmass            = 0.0
-    plant%r_cton_leaf      = 0.0
-    plant%r_ntoc_leaf      = 0.0
+    plant(:)%narea            = 0.0
+    plant(:)%narea_metabolic  = 0.0
+    plant(:)%narea_structural = 0.0
+    plant(:)%lma              = 0.0
+    plant(:)%sla              = 0.0
+    plant(:)%nmass            = 0.0
+    plant(:)%r_cton_leaf      = 0.0
+    plant(:)%r_ntoc_leaf      = 0.0
 
-  end subroutine initpft
+    do pft=1,npft
+      plant(pft)%pftno = pft
+      plant(pft)%pleaf = orgpool()
+    end do
+
+  end subroutine init_plant
 
 
   ! subroutine initdaily_plant( plant_fluxes )
